from enum import Enum

class TextToCompanySearchResponse200OutputSearchParamsOfficeLocationsV2Type0AllOfType0ItemType2LocationType0Strategy(str, Enum):
    RADIAL_DISTANCE = "radial-distance"

    def __str__(self) -> str:
        return str(self.value)
