from enum import Enum

class CompanySearchBodySearchParamsEmployeesType0RulesItemEmployeesToMatchType1Tag(str, Enum):
    FINITERANGE = "finiteRange"

    def __str__(self) -> str:
        return str(self.value)
