from enum import Enum

class TextToCombinedSearchResponse200OutputCompanySearchParamsType0OfficeLocationsV2Type0AnyOfType0ItemType2Type(str, Enum):
    GEOGRAPHY = "geography"

    def __str__(self) -> str:
        return str(self.value)
