from enum import Enum

class CompanySearchBodySearchParamsAcceleratorsV2Type0AnyOfType0ItemBatchSelectionType0Strategy(str, Enum):
    ALL_BATCHES = "all-batches"

    def __str__(self) -> str:
        return str(self.value)
