from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset







T = TypeVar("T", bound="GetProspectExclusionListsResponse200OutputItem")



@_attrs_define
class GetProspectExclusionListsResponse200OutputItem:
    """ 
        Attributes:
            list_id (str): Id of the prospect exclusion list
            name (str): Name of the prospect exclusion list
     """

    list_id: str
    name: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        list_id = self.list_id

        name = self.name


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "listId": list_id,
            "name": name,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        list_id = d.pop("listId")

        name = d.pop("name")

        get_prospect_exclusion_lists_response_200_output_item = cls(
            list_id=list_id,
            name=name,
        )


        get_prospect_exclusion_lists_response_200_output_item.additional_properties = d
        return get_prospect_exclusion_lists_response_200_output_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
