from enum import Enum

class PeopleSearchCountBodySearchParamsTimeZoneType0AnyOfItemStrategyType0Mode(str, Enum):
    MIDPOINT_WITH_BUFFER = "midpoint-with-buffer"

    def __str__(self) -> str:
        return str(self.value)
