from enum import IntEnum

class TextToCompanySearchParamsResponse200OutputSearchParamsEmployeeCountV2Type0LowerBoundExclusiveType2(IntEnum):
    VALUE_10 = 10

    def __str__(self) -> str:
        return str(self.value)
