from enum import Enum

class CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType0Rule(str, Enum):
    TOTAL = "total"

    def __str__(self) -> str:
        return str(self.value)
