from enum import Enum

class PeopleSearchBodySearchParamsJobTitleV2Type0AllOfType0ItemType1Type(str, Enum):
    STATIC_GROUPS = "static-groups"

    def __str__(self) -> str:
        return str(self.value)
