from enum import Enum

class CreateSavedSearchBodySearchParamsType1CompanySearchParamsTechnologiesType0AllOfType0ItemType1Type(str, Enum):
    CUSTOM = "custom"

    def __str__(self) -> str:
        return str(self.value)
