from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="CreateSavedSearchBodySearchParamsType0CompanySearchParamsSpecialFlagsType0")



@_attrs_define
class CreateSavedSearchBodySearchParamsType0CompanySearchParamsSpecialFlagsType0:
    """ 
        Attributes:
            exclude_yc_companies (Union[None, Unset, bool]):
     """

    exclude_yc_companies: Union[None, Unset, bool] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        exclude_yc_companies: Union[None, Unset, bool]
        if isinstance(self.exclude_yc_companies, Unset):
            exclude_yc_companies = UNSET
        else:
            exclude_yc_companies = self.exclude_yc_companies


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if exclude_yc_companies is not UNSET:
            field_dict["excludeYcCompanies"] = exclude_yc_companies

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_exclude_yc_companies(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        exclude_yc_companies = _parse_exclude_yc_companies(d.pop("excludeYcCompanies", UNSET))


        create_saved_search_body_search_params_type_0_company_search_params_special_flags_type_0 = cls(
            exclude_yc_companies=exclude_yc_companies,
        )


        create_saved_search_body_search_params_type_0_company_search_params_special_flags_type_0.additional_properties = d
        return create_saved_search_body_search_params_type_0_company_search_params_special_flags_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
