from enum import Enum

class CreateSavedSearchBodySearchParamsType1CompanySearchParamsExactCompanyV2Type0AnyOfType0ItemType0Identifier(str, Enum):
    DOMAIN = "domain"

    def __str__(self) -> str:
        return str(self.value)
