from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.sync_contact_enrichment_response_200_output_profile_emails_item_status import SyncContactEnrichmentResponse200OutputProfileEmailsItemStatus
from ..models.sync_contact_enrichment_response_200_output_profile_emails_item_type import SyncContactEnrichmentResponse200OutputProfileEmailsItemType
from ..types import UNSET, Unset
from typing import Union






T = TypeVar("T", bound="SyncContactEnrichmentResponse200OutputProfileEmailsItem")



@_attrs_define
class SyncContactEnrichmentResponse200OutputProfileEmailsItem:
    """ 
        Attributes:
            email (str):
            type_ (SyncContactEnrichmentResponse200OutputProfileEmailsItemType):
            status (Union[Unset, SyncContactEnrichmentResponse200OutputProfileEmailsItemStatus]):
     """

    email: str
    type_: SyncContactEnrichmentResponse200OutputProfileEmailsItemType
    status: Union[Unset, SyncContactEnrichmentResponse200OutputProfileEmailsItemStatus] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        email = self.email

        type_ = self.type_.value

        status: Union[Unset, str] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value



        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "email": email,
            "type": type_,
        })
        if status is not UNSET:
            field_dict["status"] = status

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        email = d.pop("email")

        type_ = SyncContactEnrichmentResponse200OutputProfileEmailsItemType(d.pop("type"))




        _status = d.pop("status", UNSET)
        status: Union[Unset, SyncContactEnrichmentResponse200OutputProfileEmailsItemStatus]
        if isinstance(_status,  Unset):
            status = UNSET
        else:
            status = SyncContactEnrichmentResponse200OutputProfileEmailsItemStatus(_status)




        sync_contact_enrichment_response_200_output_profile_emails_item = cls(
            email=email,
            type_=type_,
            status=status,
        )


        sync_contact_enrichment_response_200_output_profile_emails_item.additional_properties = d
        return sync_contact_enrichment_response_200_output_profile_emails_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
