from enum import Enum

class TextToCombinedSearchResponse200OutputCompanySearchParamsType0OfficeLocationsV2Type0AnyOfType0ItemType2LocationType0RadiusType1Unit(str, Enum):
    KILOMETERS = "kilometers"

    def __str__(self) -> str:
        return str(self.value)
