from enum import Enum

class TextToProfileSearchResponse200OutputSearchParamsEducationType0AnyOfType0ItemFinishedSchoolAtType0Strategy(str, Enum):
    ABSOLUTE = "absolute"

    def __str__(self) -> str:
        return str(self.value)
