from enum import Enum

class CreateSavedSearchBodySearchParamsType1CompanySearchParamsJobPostingsV2Type0AllOfType0ItemIndustryType0Item(str, Enum):
    ADMINISTRATIVE_SERVICES = "Administrative Services"
    AEROSPACE_MILITARY = "Aerospace & Military"
    ARTIFICIAL_INTELLIGENCE = "Artificial Intelligence"
    ARTS_MUSIC = "Arts & Music"
    AUTOMOTIVE = "Automotive"
    BUSINESS_SERVICES = "Business Services"
    CLOUD = "Cloud"
    CONSTRUCTION = "Construction"
    CONSULTING = "Consulting"
    CONSUMER_GOODS = "Consumer Goods"
    CONSUMER_SERVICES = "Consumer Services"
    DESIGN = "Design"
    EDUCATION = "Education"
    ENERGY = "Energy"
    ENTERTAINMENT = "Entertainment"
    ENVIRONMENTAL = "Environmental"
    EVENTS = "Events"
    FARMING_AGRICULTURE = "Farming & Agriculture"
    FINANCE = "Finance"
    FOOD_BEVERAGE = "Food & Beverage"
    GAMING = "Gaming"
    GOVERNMENT = "Government"
    HARDWARE = "Hardware"
    HEALTHCARE = "Healthcare"
    HOSPITALITY = "Hospitality"
    INDUSTRIALS = "Industrials"
    INFORMATION_TECHNOLOGY = "Information Technology"
    INSURANCE = "Insurance"
    LEGAL = "Legal"
    LIFE_SCIENCES = "Life Sciences"
    LOGISTICS = "Logistics"
    MANUFACTURING = "Manufacturing"
    MARKETING_ADVERTISING = "Marketing & Advertising"
    MEDIA = "Media"
    MINING = "Mining"
    NONPROFIT = "Nonprofit"
    PUBLISHING = "Publishing"
    REAL_ESTATE = "Real Estate"
    RETAIL = "Retail"
    SCIENCE_ENGINEERING = "Science & Engineering"
    SECURITY = "Security"
    SOFTWARE = "Software"
    SPORTS = "Sports"
    TELECOM = "Telecom"
    TRADE = "Trade"
    TRANSPORTATION = "Transportation"
    TRAVEL_TOURISM = "Travel & Tourism"
    UTILITIES = "Utilities"
    VENTURE_CAPITAL = "Venture Capital"

    def __str__(self) -> str:
        return str(self.value)
