from enum import Enum

class CompanyCountBodySearchParamsRevenueUSDType0MaxType0SuffixType2Type1(str, Enum):
    B = "B"
    K = "K"
    M = "M"
    T = "T"

    def __str__(self) -> str:
        return str(self.value)
