from enum import Enum

class CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType6Rule(str, Enum):
    INDUSTRY = "industry"

    def __str__(self) -> str:
        return str(self.value)
