from enum import IntEnum

class SyncCombinedSearchBodyCompanyParamsEmployeeCountV2Type0LowerBoundExclusiveType0(IntEnum):
    VALUE_0 = 0

    def __str__(self) -> str:
        return str(self.value)
