from enum import IntEnum

class CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeeCountV2Type0UpperBoundInclusiveType4(IntEnum):
    VALUE_200 = 200

    def __str__(self) -> str:
        return str(self.value)
