from enum import Enum

class TextToCompanySearchResponse200OutputSearchParamsExactCompanyV2Type0AnyOfType0ItemType3Identifier(str, Enum):
    ADVANCED = "advanced"

    def __str__(self) -> str:
        return str(self.value)
