from enum import IntEnum

class TextToCompanySearchParamsResponse200OutputSearchParamsEmployeeCountV2Type0UpperBoundInclusiveType3(IntEnum):
    VALUE_50 = 50

    def __str__(self) -> str:
        return str(self.value)
