from enum import Enum

class CreateSavedSearchBodySearchParamsType1CompanySearchParamsTechnologiesType0NoneOfType0ItemType0Technology(str, Enum):
    AIRFLOW = "Airflow"
    ALGOLIA = "Algolia"
    AMPLITUDE = "Amplitude"
    ANGULAR = "Angular"
    ANSIBLE = "Ansible"
    ANTHROPIC = "Anthropic"
    APACHE = "Apache"
    APACHE_SPARK = "Apache Spark"
    AWS = "AWS"
    AZURE = "Azure"
    AZURE_DEVOPS = "Azure DevOps"
    BIGQUERY = "BigQuery"
    BITBUCKET = "Bitbucket"
    BOOTSTRAP = "Bootstrap"
    C = "C++"
    CASSANDRA = "Cassandra"
    CIRCLECI = "CircleCI"
    CLICKHOUSE = "ClickHouse"
    CLOUDFLARE = "Cloudflare"
    CLOUDINARY = "Cloudinary"
    COCKROACHDB = "CockroachDB"
    CONFLUENCE = "Confluence"
    CONTENTFUL = "Contentful"
    CUDA = "CUDA"
    CURSOR = "Cursor"
    CYPRESS = "Cypress"
    DATABRICKS = "Databricks"
    DATADOG = "Datadog"
    DBT = "dbt"
    DJANGO = "Django"
    DOCKER = "Docker"
    DYNAMODB = "DynamoDB"
    ELASTICSEARCH = "Elasticsearch"
    ELIXIR = "Elixir"
    ELK_STACK = "ELK Stack"
    EXPRESS = "Express"
    FASTIFY = "Fastify"
    FIREBASE = "Firebase"
    FLASK = "Flask"
    FLY_IO = "Fly.io"
    GITHUB = "GitHub"
    GITLAB = "GitLab"
    GO = "Go"
    GOOGLE_ANALYTICS = "Google Analytics"
    GOOGLE_CLOUD = "Google Cloud"
    GRAFANA = "Grafana"
    GRAPHQL = "GraphQL"
    GUSTO = "Gusto"
    HADOOP = "Hadoop"
    HASURA = "Hasura"
    HELM = "Helm"
    HUBSPOT = "HubSpot"
    INFLUXDB = "InfluxDB"
    INTERCOM = "Intercom"
    JAVA = "Java"
    JAVASCRIPT = "JavaScript"
    JENKINS = "Jenkins"
    JIRA = "Jira"
    JUPYTER = "Jupyter"
    KAFKA = "Kafka"
    KERAS = "Keras"
    KLAVIYO = "Klaviyo"
    KOTLIN = "Kotlin"
    KUBEFLOW = "Kubeflow"
    KUBERNETES = "Kubernetes"
    LANGCHAIN = "LangChain"
    LARAVEL = "Laravel"
    LOOKER = "Looker"
    MAGENTO = "Magento"
    MARKETO = "Marketo"
    MICROSOFT_TEAMS = "Microsoft Teams"
    MIXPANEL = "Mixpanel"
    MONGODB = "MongoDB"
    MYSQL = "MySQL"
    NEO4J = "Neo4j"
    NESTJS = "NestJS"
    NETLIFY = "Netlify"
    NEW_RELIC = "New Relic"
    NEXT_JS = "Next.js"
    NGINX = "Nginx"
    NODE_JS = "Node.js"
    NOTION = "Notion"
    NUMPY = "NumPy"
    OPENAI = "OpenAI"
    OPENSEARCH = "OpenSearch"
    PAGERDUTY = "PagerDuty"
    PHP = "PHP"
    PLANETSCALE = "PlanetScale"
    PLAYWRIGHT = "Playwright"
    POSTGRESQL = "PostgreSQL"
    POWER_BI = "Power BI"
    PRISMA = "Prisma"
    PROMETHEUS = "Prometheus"
    PUPPETEER = "Puppeteer"
    PYTHON = "Python"
    PYTORCH = "PyTorch"
    RABBITMQ = "RabbitMQ"
    RAILWAY = "Railway"
    REACT = "React"
    REDIS = "Redis"
    REDSHIFT = "Redshift"
    RENDER = "Render"
    RIPPLING = "Rippling"
    RUBY = "Ruby"
    RUST = "Rust"
    SALESFORCE = "Salesforce"
    SCALA = "Scala"
    SCIKIT_LEARN = "Scikit-learn"
    SEGMENT = "Segment"
    SELENIUM = "Selenium"
    SENTRY = "Sentry"
    SERVICENOW = "ServiceNow"
    SHOPIFY = "Shopify"
    SLACK = "Slack"
    SNOWFLAKE = "Snowflake"
    SOLR = "Solr"
    SPLUNK = "Splunk"
    SPRING_BOOT = "Spring Boot"
    SQL = "SQL"
    SQLITE = "SQLite"
    STRIPE = "Stripe"
    SUPABASE = "Supabase"
    SWIFT = "Swift"
    TABLEAU = "Tableau"
    TAILWIND_CSS = "Tailwind CSS"
    TENSORFLOW = "TensorFlow"
    TERRAFORM = "Terraform"
    TIMESCALEDB = "TimescaleDB"
    TRAVIS_CI = "Travis CI"
    TWILIO = "Twilio"
    TYPESCRIPT = "TypeScript"
    VERCEL = "Vercel"
    VUE_JS = "Vue.js"
    WEBFLOW = "Webflow"
    WEIGHTS_BIASES = "Weights & Biases"
    WINDSURF = "Windsurf"
    WOOCOMMERCE = "WooCommerce"
    WORDPRESS = "WordPress"
    ZAPIER = "Zapier"
    ZENDESK = "Zendesk"

    def __str__(self) -> str:
        return str(self.value)
