from enum import Enum

class TextToCombinedSearchResponse200OutputProfileSearchParamsType0EducationType0AnyOfType0ItemSchoolV3Type0NoneOfType0ItemSourceType1(str, Enum):
    CSV = "csv"

    def __str__(self) -> str:
        return str(self.value)
