from enum import Enum

class CompanySearchBodySearchParamsJobPostingStatsType0AnyOfType0ItemType4RangeType0Type(str, Enum):
    COUNT_RANGE = "count-range"

    def __str__(self) -> str:
        return str(self.value)
