from enum import Enum

class SyncCombinedSearchResponse200OutputCompaniesItemRoleCountMatchesType0ItemNumMatchingEmployeesType2Type(str, Enum):
    NONE = "none"

    def __str__(self) -> str:
        return str(self.value)
