from enum import Enum

class TextToProfileSearchResponse200OutputSearchParamsEducationType0AllOfType0ItemSchoolV3Type0AnyOfType0ItemSourceType2Type1(str, Enum):
    CSV = "csv"

    def __str__(self) -> str:
        return str(self.value)
