from enum import IntEnum

class SyncCombinedSearchBodyCompanyParamsEmployeeCountV2Type0UpperBoundInclusiveType6(IntEnum):
    VALUE_1000 = 1000

    def __str__(self) -> str:
        return str(self.value)
