from enum import Enum

class CreateSavedSearchBodySearchParamsType1CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType4Rule(str, Enum):
    JOB_FUNCTION = "job-function"

    def __str__(self) -> str:
        return str(self.value)
