from enum import Enum

class KitchenSinkCompanyResponse200OutputDataItemRoleCountMatchesType0ItemNumMatchingEmployeesType3Type(str, Enum):
    NOT_MATCHED = "not-matched"

    def __str__(self) -> str:
        return str(self.value)
