from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.company_count_body_search_params_job_posting_stats_type_0_any_of_type_0_item_type_0_rule import CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0Rule
from typing import cast

if TYPE_CHECKING:
  from ..models.company_count_body_search_params_job_posting_stats_type_0_any_of_type_0_item_type_0_count import CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0Count





T = TypeVar("T", bound="CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0")



@_attrs_define
class CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0:
    """ 
        Attributes:
            rule (CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0Rule):
            count (CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0Count):
     """

    rule: CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0Rule
    count: 'CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0Count'
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.company_count_body_search_params_job_posting_stats_type_0_any_of_type_0_item_type_0_count import CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0Count
        rule = self.rule.value

        count = self.count.to_dict()


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "rule": rule,
            "count": count,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.company_count_body_search_params_job_posting_stats_type_0_any_of_type_0_item_type_0_count import CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0Count
        d = dict(src_dict)
        rule = CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0Rule(d.pop("rule"))




        count = CompanyCountBodySearchParamsJobPostingStatsType0AnyOfType0ItemType0Count.from_dict(d.pop("count"))




        company_count_body_search_params_job_posting_stats_type_0_any_of_type_0_item_type_0 = cls(
            rule=rule,
            count=count,
        )


        company_count_body_search_params_job_posting_stats_type_0_any_of_type_0_item_type_0.additional_properties = d
        return company_count_body_search_params_job_posting_stats_type_0_any_of_type_0_item_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
