from enum import Enum

class CombinedSearchBodyProfileParamsLanguagesType0AllOfType0Item(str, Enum):
    AFRIKAANS = "Afrikaans"
    AKAN = "Akan"
    ALBANIAN = "Albanian"
    ALSATIAN = "Alsatian"
    AMHARIC = "Amharic"
    ARABIC = "Arabic"
    ARMENIAN = "Armenian"
    ASSAMESE = "Assamese"
    ASSYRIAN = "Assyrian"
    AWADHI = "Awadhi"
    AZERBAIJANI = "Azerbaijani"
    BALINESE = "Balinese"
    BALOCHI = "Balochi"
    BAMBARA = "Bambara"
    BASQUE = "Basque"
    BELARUSIAN = "Belarusian"
    BEMBA = "Bemba"
    BENGALI = "Bengali"
    BHOJPURI = "Bhojpuri"
    BISAYA = "Bisaya"
    BOSNIAN = "Bosnian"
    BRETON = "Breton"
    BULGARIAN = "Bulgarian"
    BURMESE = "Burmese"
    CANTONESE = "Cantonese"
    CATALAN = "Catalan"
    CEBUANO = "Cebuano"
    CROATIAN = "Croatian"
    CZECH = "Czech"
    DANISH = "Danish"
    DARI = "Dari"
    DHIVEHI = "Dhivehi"
    DHOLUO = "Dholuo"
    DOGRI = "Dogri"
    DUTCH = "Dutch"
    DZONGKHA = "Dzongkha"
    EFIK = "Efik"
    ENGLISH = "English"
    ESPERANTO = "Esperanto"
    ESTONIAN = "Estonian"
    EWE = "Ewe"
    FANTE = "Fante"
    FAROESE = "Faroese"
    FIJIAN = "Fijian"
    FINNISH = "Finnish"
    FLEMISH = "Flemish"
    FON = "Fon"
    FRENCH = "French"
    FRISIAN = "Frisian"
    FULA = "Fula"
    GA = "Ga"
    GALICIAN = "Galician"
    GARHWALI = "Garhwali"
    GEORGIAN = "Georgian"
    GERMAN = "German"
    GREEK = "Greek"
    GUARANI = "Guarani"
    GUJARATI = "Gujarati"
    HAITIAN_CREOLE = "Haitian Creole"
    HAKKA = "Hakka"
    HARYANVI = "Haryanvi"
    HAUSA = "Hausa"
    HAWAIIAN = "Hawaiian"
    HEBREW = "Hebrew"
    HILIGAYNON = "Hiligaynon"
    HINDI = "Hindi"
    HINDKO = "Hindko"
    HMONG = "Hmong"
    HUNGARIAN = "Hungarian"
    IBAN = "Iban"
    IBIBIO = "Ibibio"
    ICELANDIC = "Icelandic"
    IGALA = "Igala"
    IGBO = "Igbo"
    ILOCANO = "Ilocano"
    INDONESIAN = "Indonesian"
    IRISH = "Irish"
    ITALIAN = "Italian"
    JAPANESE = "Japanese"
    JAVANESE = "Javanese"
    KABYLE = "Kabyle"
    KAMBA = "Kamba"
    KANNADA = "Kannada"
    KAPAMPANGAN = "Kapampangan"
    KASHMIRI = "Kashmiri"
    KAZAKH = "Kazakh"
    KHMER = "Khmer"
    KIKUYU = "Kikuyu"
    KINYARWANDA = "Kinyarwanda"
    KIRUNDI = "Kirundi"
    KONGO = "Kongo"
    KONKANI = "Konkani"
    KOREAN = "Korean"
    KRIO = "Krio"
    KURDISH = "Kurdish"
    KUTCHI = "Kutchi"
    KYRGYZ = "Kyrgyz"
    LAO = "Lao"
    LATIN = "Latin"
    LATVIAN = "Latvian"
    LIMBURGISH = "Limburgish"
    LINGALA = "Lingala"
    LITHUANIAN = "Lithuanian"
    LOZI = "Lozi"
    LUGANDA = "Luganda"
    LUHYA = "Luhya"
    LUXEMBOURGISH = "Luxembourgish"
    MACEDONIAN = "Macedonian"
    MAGAHI = "Magahi"
    MAITHILI = "Maithili"
    MALAGASY = "Malagasy"
    MALAY = "Malay"
    MALAYALAM = "Malayalam"
    MALTESE = "Maltese"
    MANDARIN = "Mandarin"
    MANDINKA = "Mandinka"
    MANIPURI = "Manipuri"
    MAORI = "Maori"
    MARATHI = "Marathi"
    MARWARI = "Marwari"
    MAURITIAN_CREOLE = "Mauritian Creole"
    MINANGKABAU = "Minangkabau"
    MONGOLIAN = "Mongolian"
    MONTENEGRIN = "Montenegrin"
    NAVAJO = "Navajo"
    NEPALI = "Nepali"
    NEWAR = "Newar"
    NORTHERN_NDEBELE = "Northern Ndebele"
    NORTHERN_SOTHO = "Northern Sotho"
    NORTH_FRISIAN = "North Frisian"
    NORWEGIAN = "Norwegian"
    NYANJA = "Nyanja"
    ODIA = "Odia"
    OROMO = "Oromo"
    OVAMBO = "Ovambo"
    PAPIAMENTO = "Papiamento"
    PASHTO = "Pashto"
    PERSIAN = "Persian"
    POLISH = "Polish"
    PORTUGUESE = "Portuguese"
    PUNJABI = "Punjabi"
    PUTONGHUA = "Putonghua"
    QUECHUA = "Quechua"
    RAJASTHANI = "Rajasthani"
    ROMANIAN = "Romanian"
    RUSSIAN = "Russian"
    SAMOAN = "Samoan"
    SANSKRIT = "Sanskrit"
    SARAIKI = "Saraiki"
    SAURASHTRA = "Saurashtra"
    SCOTTISH_GAELIC = "Scottish Gaelic"
    SERBIAN = "Serbian"
    SHANGHAINESE = "Shanghainese"
    SHONA = "Shona"
    SIGN_LANGUAGES = "Sign Languages"
    SINDHI = "Sindhi"
    SINHALESE = "Sinhalese"
    SLOVAK = "Slovak"
    SLOVENIAN = "Slovenian"
    SOGA = "Soga"
    SOMALI = "Somali"
    SOUTHERN_MIN = "Southern Min"
    SOUTHERN_NDEBELE = "Southern Ndebele"
    SOUTHERN_SOTHO = "Southern Sotho"
    SPANISH = "Spanish"
    SRANAN_TONGO = "Sranan Tongo"
    SUNDANESE = "Sundanese"
    SWAHILI = "Swahili"
    SWAZI = "Swazi"
    SWEDISH = "Swedish"
    TAGALOGFILIPINO = "Tagalog/Filipino"
    TAIWANESE_HOKKIEN = "Taiwanese Hokkien"
    TAJIK = "Tajik"
    TAMAZIGHT = "Tamazight"
    TAMIL = "Tamil"
    TATAR = "Tatar"
    TELUGU = "Telugu"
    TEOCHEW = "Teochew"
    TETUM = "Tetum"
    THAI = "Thai"
    TIBETAN = "Tibetan"
    TIGRINYA = "Tigrinya"
    TOK_PISIN = "Tok Pisin"
    TONGAN = "Tongan"
    TSONGA = "Tsonga"
    TSWANA = "Tswana"
    TULU = "Tulu"
    TUMBUKA = "Tumbuka"
    TURKISH = "Turkish"
    TURKMEN = "Turkmen"
    TWI = "Twi"
    UKRAINIAN = "Ukrainian"
    URDU = "Urdu"
    UYGHUR = "Uyghur"
    UZBEK = "Uzbek"
    VALENCIAN = "Valencian"
    VENDA = "Venda"
    VIETNAMESE = "Vietnamese"
    WARAY = "Waray"
    WELSH = "Welsh"
    WOLOF = "Wolof"
    XHOSA = "Xhosa"
    YIDDISH = "Yiddish"
    YORUBA = "Yoruba"
    ZULU = "Zulu"

    def __str__(self) -> str:
        return str(self.value)
