from enum import Enum

class PeopleSearchCountBodySearchParamsJobTitleV3Type0NoneOfType0ItemType1Type(str, Enum):
    FUNCTIONAL = "functional"

    def __str__(self) -> str:
        return str(self.value)
