from enum import Enum

class KitchenSinkBulkProfileBodyProfilesItemCompanyIdentifierType0Identifier(str, Enum):
    LINKEDINSLUG = "linkedinSlug"

    def __str__(self) -> str:
        return str(self.value)
