from enum import IntEnum

class CompanySearchBodySearchParamsEmployeeCountV2Type0LowerBoundExclusiveType8(IntEnum):
    VALUE_10000 = 10000

    def __str__(self) -> str:
        return str(self.value)
