from enum import Enum

class TextToCombinedSearchResponse200OutputProfileSearchParamsType0LocationType0SubtractAllType0ItemType0RadiusType1Unit(str, Enum):
    KILOMETERS = "kilometers"

    def __str__(self) -> str:
        return str(self.value)
