from enum import Enum

class ProfileLiveEnrichResponse200ProfileFoundAndEnrichedProfileExperiencesType0ItemJobFunctionType0Item(str, Enum):
    ACCOUNTING = "Accounting"
    ADMINISTRATIVE = "Administrative"
    ADVERTISING = "Advertising"
    ANALYST = "Analyst"
    ARTS_AND_DESIGN = "Arts and Design"
    ART_CREATIVE = "Art / Creative"
    BUSINESS_DEVELOPMENT = "Business Development"
    COMMUNITY_SOCIAL_SERVICES = "Community & Social Services"
    CONSULTING = "Consulting"
    CUSTOMER_SERVICE = "Customer Service"
    DESIGN = "Design"
    DISTRIBUTION = "Distribution"
    EDUCATION = "Education"
    ENGINEERING = "Engineering"
    ENTREPRENEURSHIP = "Entrepreneurship"
    FINANCE = "Finance"
    GENERAL_BUSINESS = "General Business"
    HEALTHCARE_SERVICES = "Healthcare Services"
    HEALTH_CARE_PROVIDER = "Health Care Provider"
    HUMAN_RESOURCES = "Human Resources"
    INFORMATION_TECHNOLOGY = "Information Technology"
    LEGAL = "Legal"
    MANAGEMENT = "Management"
    MANUFACTURING = "Manufacturing"
    MARKETING = "Marketing"
    MILITARY_PROTECTIVE_SERVICES = "Military & Protective Services"
    OPERATIONS = "Operations"
    OTHER = "Other"
    PRODUCTION = "Production"
    PRODUCT_MANAGEMENT = "Product Management"
    PROGRAM_PRODUCT_MANAGEMENT = "Program & Product Management"
    PROJECT_MANAGEMENT = "Project Management"
    PUBLIC_RELATIONS = "Public Relations"
    PURCHASING = "Purchasing"
    QUALITY_ASSURANCE = "Quality Assurance"
    REAL_ESTATE = "Real Estate"
    RESEARCH = "Research"
    SALES = "Sales"
    SCIENCE = "Science"
    STRATEGY_PLANNING = "Strategy / Planning"
    SUPPLY_CHAIN = "Supply Chain"
    SUPPORT = "Support"
    TRAINING = "Training"
    WRITING_EDITING = "Writing / Editing"

    def __str__(self) -> str:
        return str(self.value)
