from enum import Enum

class CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0AnyOfType0ItemType1Rule(str, Enum):
    COUNTRY = "country"

    def __str__(self) -> str:
        return str(self.value)
