from enum import Enum

class CompanyCountBodySearchParamsJobPostingStatsType0AllOfType0ItemType5Rule(str, Enum):
    LOCATION_TYPE = "location-type"

    def __str__(self) -> str:
        return str(self.value)
