from enum import Enum

class TextToCompanySearchParamsResponse200OutputSearchParamsFoundedOnType1Strategy(str, Enum):
    RELATIVE = "relative"

    def __str__(self) -> str:
        return str(self.value)
