from enum import Enum

class CombinedSearchBodyCompanyParamsOfficeLocationsV2Type0AllOfType0ItemType0Type(str, Enum):
    WORLDWIDE = "worldwide"

    def __str__(self) -> str:
        return str(self.value)
