from enum import Enum

class SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysNoneType0ItemCountCriteriaType1Type(str, Enum):
    PERCENT_CHANGE = "percent_change"

    def __str__(self) -> str:
        return str(self.value)
