from enum import Enum

class TextToCompanySearchResponse200OutputSearchParamsAcceleratorsV2Type0NoneOfType0ItemBatchSelectionType1Strategy(str, Enum):
    ONLY_THESE_BATCHES = "only-these-batches"

    def __str__(self) -> str:
        return str(self.value)
