from enum import Enum

class CreateSavedSearchBodySearchParamsType2ProfileSearchParamsStealthV2Type1Status(str, Enum):
    LEFT_STEALTH = "left-stealth"

    def __str__(self) -> str:
        return str(self.value)
