from enum import Enum

class SyncCombinedSearchBodyCompanyParamsEmployeeTrendsType0ObeysAnyType0ItemCountCriteriaType0Type(str, Enum):
    NUMERIC_CHANGE = "numeric_change"

    def __str__(self) -> str:
        return str(self.value)
