from enum import Enum

class TextToProfileSearchParamsResponse200OutputSearchParamsLocationType0UnionAllType0ItemType0RadiusType0Unit(str, Enum):
    MILES = "miles"

    def __str__(self) -> str:
        return str(self.value)
