from enum import Enum

class CombinedSearchBodyProfileParamsJobTitleV2Type0AllOfType0ItemType2Type(str, Enum):
    DYNAMIC_GROUPS = "dynamic-groups"

    def __str__(self) -> str:
        return str(self.value)
