from enum import Enum

class CompanyCountBodySearchParamsJobPostingStatsType0NoneOfType0ItemType1RangeType1Type(str, Enum):
    PERCENT_RANGE = "percent-range"

    def __str__(self) -> str:
        return str(self.value)
