from enum import Enum

class CompanySearchBodySearchParamsJobPostingsV2Type0AnyOfType0ItemGeoLocationType0Strategy(str, Enum):
    RADIAL_DISTANCE = "radial-distance"

    def __str__(self) -> str:
        return str(self.value)
