from enum import Enum

class GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyRoleCountMatchesType0ItemNumMatchingEmployeesType1Type(str, Enum):
    ALL = "all"

    def __str__(self) -> str:
        return str(self.value)
