from enum import Enum

class CombinedSearchBodyCompanyParamsCrunchbaseCategoryGroupsType0AnyOfType0ItemType(str, Enum):
    GROUP = "group"

    def __str__(self) -> str:
        return str(self.value)
