from enum import Enum

class SyncCombinedSearchBodyCompanyParamsTechnologiesType0AnyOfType0ItemType0Type(str, Enum):
    PREDEFINED = "predefined"

    def __str__(self) -> str:
        return str(self.value)
