from enum import Enum

class CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0AnyOfType0ItemType2Rule(str, Enum):
    SENIORITY = "seniority"

    def __str__(self) -> str:
        return str(self.value)
