from enum import Enum

class CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType1Identifier(str, Enum):
    LINKEDIN_URL = "linkedin-url"

    def __str__(self) -> str:
        return str(self.value)
