from enum import Enum

class CreateSavedSearchBodySearchParamsType0CompanySearchParamsEmployeesType0RulesItemEmployeesToMatchType0Tag(str, Enum):
    ALL = "all"

    def __str__(self) -> str:
        return str(self.value)
