from enum import Enum

class SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AllOfType0ItemPostedAtType1WindowType0Method(str, Enum):
    LASTN = "lastN"

    def __str__(self) -> str:
        return str(self.value)
