from enum import IntEnum

class CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeeCountV2Type0LowerBoundExclusiveType5(IntEnum):
    VALUE_500 = 500

    def __str__(self) -> str:
        return str(self.value)
