from enum import Enum

class CreateSavedSearchBodySearchParamsType0CompanySearchParamsOfficeLocationsV2Type0NoneOfType0ItemType2Type(str, Enum):
    GEOGRAPHY = "geography"

    def __str__(self) -> str:
        return str(self.value)
