from enum import Enum

class CreateSavedSearchBodySearchParamsType1CompanySearchParamsEmployeeTrendsType0ObeysNoneType0ItemCountCriteriaType2Type(str, Enum):
    CURRENT_COUNT = "current_count"

    def __str__(self) -> str:
        return str(self.value)
