from enum import Enum

class SyncCombinedSearchBodyProfileParamsStealthV2Type1LeftStealthAtType1Strategy(str, Enum):
    RELATIVE = "relative"

    def __str__(self) -> str:
        return str(self.value)
