from enum import Enum

class TextToCompanySearchParamsResponse200OutputSearchParamsTechnologiesType0AllOfType0ItemType1Type(str, Enum):
    CUSTOM = "custom"

    def __str__(self) -> str:
        return str(self.value)
