from enum import Enum

class CompanyCountBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType2Identifier(str, Enum):
    LINKEDIN_ORG_ID = "linkedin-org-id"

    def __str__(self) -> str:
        return str(self.value)
