from enum import Enum

class SyncCombinedSearchBodyProfileParamsJobTitleV2Type0AnyOfType0ItemType1Type(str, Enum):
    STATIC_GROUPS = "static-groups"

    def __str__(self) -> str:
        return str(self.value)
