from enum import Enum

class CompanySearchBodySearchParamsOfficeLocationsV2Type0AllOfType0ItemType1Type(str, Enum):
    COUNTRY_OR_REGION = "country-or-region"

    def __str__(self) -> str:
        return str(self.value)
