from enum import Enum

class CombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemPostedAtType1WindowType0Method(str, Enum):
    LASTN = "lastN"

    def __str__(self) -> str:
        return str(self.value)
