from enum import Enum

class SyncCombinedSearchBodyProfileParamsEducationType0AllOfType0ItemStartedSchoolAtType1WindowType2Method(str, Enum):
    CALENDAR = "calendar"

    def __str__(self) -> str:
        return str(self.value)
