from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import Union

if TYPE_CHECKING:
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0aze import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AZE
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0hkg import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HKG
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lbn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LBN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sur import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SUR
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mhl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MHL
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0hnd import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HND
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lca import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LCA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0brb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BRB
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gib import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GIB
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pol import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0POL
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0kor import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KOR
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mmr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MMR
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mus import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MUS
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0asm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ASM
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gha import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GHA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0slv import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SLV
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bra import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BRA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0rwa import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0RWA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0npl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NPL
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0kaz import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KAZ
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0myt import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MYT
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0isr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ISR
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0fro import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FRO
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0chl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CHL
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tgo import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TGO
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ala import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ALA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sau import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SAU
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ind import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IND
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0uzb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UZB
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bhs import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BHS
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0vct import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VCT
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0flk import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FLK
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0umi import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UMI
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mlt import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MLT
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0blz import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BLZ
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0arg import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ARG
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tjk import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TJK
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pry import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRY
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mar import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MAR
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mne import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MNE
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0som import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SOM
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gbr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GBR
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sgs import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SGS
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0prt import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRT
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0isl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ISL
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sen import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SEN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0geo import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GEO
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0reu import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0REU
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gin import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GIN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sdn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SDN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bgd import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BGD
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0jey import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JEY
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sle import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SLE
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ven import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VEN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0vir import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VIR
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sjm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SJM
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0rou import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ROU
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0irl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IRL
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0xkx import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0XKX
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0are import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ARE
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ant import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ANT
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0phl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PHL
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nzl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NZL
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nic import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NIC
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0svk import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SVK
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0grd import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GRD
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0civ import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CIV
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bel import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BEL
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0kir import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KIR
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0aia import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AIA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0slb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SLB
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0hrv import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HRV
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0zmb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ZMB
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0caf import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CAF
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ssd import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SSD
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0swz import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SWZ
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ben import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BEN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mwi import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MWI
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0niu import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NIU
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mac import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MAC
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cck import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CCK
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0dza import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DZA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tza import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TZA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nam import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NAM
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0vat import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VAT
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0dom import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DOM
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tkl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TKL
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0blm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BLM
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0eri import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ERI
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0svn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SVN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0jam import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JAM
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0imn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IMN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nfk import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NFK
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0chn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CHN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cmr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CMR
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0usa import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0USA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bih import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BIH
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mkd import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MKD
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bfa import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BFA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tur import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TUR
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0srb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SRB
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lux import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LUX
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cog import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COG
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0guy import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GUY
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tls import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TLS
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0est import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0EST
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0dma import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DMA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bes import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BES
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nld import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NLD
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0irn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IRN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bdi import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BDI
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0dji import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DJI
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0dnk import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DNK
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0glp import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GLP
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0and import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AND
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mli import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MLI
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cok import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COK
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0plw import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PLW
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mnp import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MNP
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cri import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CRI
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lka import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LKA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gnb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GNB
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ken import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KEN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0prk import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRK
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0fin import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FIN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0idn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IDN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gum import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GUM
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gnq import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GNQ
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pcn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PCN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tha import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0THA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tun import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TUN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ata import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ATA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0grc import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GRC
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0kwt import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KWT
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cpv import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CPV
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gtm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GTM
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0twn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TWN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mda import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MDA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pak import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PAK
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nru import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NRU
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0aut import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AUT
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0aus import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AUS
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0can import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CAN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0jpn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JPN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0syr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SYR
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0msr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MSR
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0spm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SPM
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0eth import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ETH
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0brn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BRN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lie import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LIE
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0maf import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MAF
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0afg import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AFG
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tto import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TTO
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0zaf import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ZAF
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bmu import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BMU
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lso import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LSO
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mtq import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MTQ
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0kna import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KNA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cxr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CXR
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bwa import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BWA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0rus import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0RUS
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bvt import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BVT
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ltu import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LTU
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mex import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MEX
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tcd import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TCD
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pan import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PAN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ago import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AGO
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ita import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ITA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lby import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LBY
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mrt import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MRT
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0esp import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ESP
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0vnm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VNM
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0omn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0OMN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0per import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PER
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0atg import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ATG
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0uga import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UGA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mng import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MNG
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0abw import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ABW
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0hun import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HUN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bol import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BOL
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cym import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CYM
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nga import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NGA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lbr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LBR
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0che import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CHE
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0irq import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IRQ
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0col import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COL
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0alb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ALB
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0smr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SMR
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0jor import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JOR
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0btn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BTN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0fra import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FRA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0hti import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HTI
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0hmd import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HMD
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sxm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SXM
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tuv import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TUV
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0fsm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FSM
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0blr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BLR
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0png import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PNG
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bgr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BGR
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lao import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LAO
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gmb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GMB
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pyf import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PYF
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cyp import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CYP
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0khm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KHM
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mdg import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MDG
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mdv import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MDV
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lva import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LVA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mys import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MYS
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cod import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COD
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nor import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NOR
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0grl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GRL
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0egy import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0EGY
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0iot import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IOT
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0com import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COM
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ner import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NER
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cze import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CZE
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0zwe import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ZWE
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0moz import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MOZ
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tkm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TKM
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ury import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0URY
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cub import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CUB
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0syc import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SYC
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ton import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TON
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0yem import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0YEM
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0guf import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GUF
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0wlf import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0WLF
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0kgz import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KGZ
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cuw import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CUW
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0vut import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VUT
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0fji import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FJI
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sgp import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SGP
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0shn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SHN
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0atf import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ATF
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gab import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GAB
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mco import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MCO
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pse import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PSE
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0swe import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SWE
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0qat import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0QAT
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pri import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRI
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0vgb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VGB
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ggy import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GGY
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ecu import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ECU
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ukr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UKR
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0wsm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0WSM
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0deu import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DEU
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0esh import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ESH
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ncl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NCL
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bhr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BHR
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0arm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ARM
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tca import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TCA
  from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0stp import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0STP





T = TypeVar("T", bound="GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0")



@_attrs_define
class GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0:
    """ 
        Attributes:
            usa (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0USA]):
            gbr (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0GBR]):
            fra (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0FRA]):
            ind (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0IND]):
            bra (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0BRA]):
            deu (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0DEU]):
            esp (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ESP]):
            can (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0CAN]):
            aus (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0AUS]):
            nld (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0NLD]):
            ita (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ITA]):
            zaf (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ZAF]):
            bel (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0BEL]):
            chn (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0CHN]):
            tur (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0TUR]):
            mex (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MEX]):
            che (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0CHE]):
            nor (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0NOR]):
            are (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ARE]):
            swe (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SWE]):
            pol (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0POL]):
            idn (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0IDN]):
            arg (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ARG]):
            prt (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0PRT]):
            col (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0COL]):
            chl (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0CHL]):
            pak (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0PAK]):
            dnk (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0DNK]):
            jpn (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0JPN]):
            nga (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0NGA]):
            sgp (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SGP]):
            per (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0PER]):
            nzl (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0NZL]):
            aut (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0AUT]):
            irl (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0IRL]):
            mys (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MYS]):
            bgd (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0BGD]):
            egy (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0EGY]):
            isr (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ISR]):
            sau (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SAU]):
            phl (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0PHL]):
            fin (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0FIN]):
            irn (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0IRN]):
            rou (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ROU]):
            cze (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0CZE]):
            grc (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0GRC]):
            hkg (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0HKG]):
            hun (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0HUN]):
            ken (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0KEN]):
            mar (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MAR]):
            vnm (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0VNM]):
            rus (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0RUS]):
            ukr (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0UKR]):
            ecu (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ECU]):
            tha (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0THA]):
            lka (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0LKA]):
            kor (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0KOR]):
            bgr (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0BGR]):
            gha (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0GHA]):
            srb (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SRB]):
            twn (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0TWN]):
            hrv (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0HRV]):
            ltu (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0LTU]):
            pri (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0PRI]):
            svk (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SVK]):
            tun (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0TUN]):
            est (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0EST]):
            ven (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0VEN]):
            cri (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0CRI]):
            pan (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0PAN]):
            ury (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0URY]):
            lbn (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0LBN]):
            lux (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0LUX]):
            cyp (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0CYP]):
            npl (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0NPL]):
            jor (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0JOR]):
            svn (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SVN]):
            mtq (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MTQ]):
            qat (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0QAT]):
            glp (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0GLP]):
            uga (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0UGA]):
            dza (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0DZA]):
            gtm (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0GTM]):
            cmr (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0CMR]):
            lva (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0LVA]):
            dom (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0DOM]):
            aze (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0AZE]):
            geo (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0GEO]):
            sen (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SEN]):
            tza (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0TZA]):
            zwe (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ZWE]):
            kwt (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0KWT]):
            mlt (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MLT]):
            omn (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0OMN]):
            bol (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0BOL]):
            slv (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SLV]):
            arm (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ARM]):
            pry (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0PRY]):
            irq (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0IRQ]):
            khm (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0KHM]):
            bih (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0BIH]):
            ago (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0AGO]):
            bhr (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0BHR]):
            alb (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ALB]):
            kaz (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0KAZ]):
            civ (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0CIV]):
            eth (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ETH]):
            mus (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MUS]):
            zmb (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ZMB]):
            mkd (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MKD]):
            cod (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0COD]):
            blr (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0BLR]):
            moz (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MOZ]):
            reu (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0REU]):
            tto (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0TTO]):
            guf (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0GUF]):
            isl (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ISL]):
            mmr (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MMR]):
            hnd (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0HND]):
            rwa (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0RWA]):
            mdg (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MDG]):
            ben (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0BEN]):
            uzb (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0UZB]):
            nam (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0NAM]):
            bwa (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0BWA]):
            mda (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MDA]):
            jey (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0JEY]):
            nic (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0NIC]):
            sdn (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SDN]):
            jam (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0JAM]):
            imn (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0IMN]):
            bfa (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0BFA]):
            mng (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MNG]):
            mne (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MNE]):
            mco (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MCO]):
            tgo (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0TGO]):
            afg (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0AFG]):
            lby (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0LBY]):
            xkx (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0XKX]):
            cym (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0CYM]):
            mwi (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MWI]):
            som (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SOM]):
            png (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0PNG]):
            mdv (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MDV]):
            mli (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MLI]):
            gin (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0GIN]):
            pse (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0PSE]):
            gab (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0GAB]):
            lie (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0LIE]):
            hti (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0HTI]):
            syr (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SYR]):
            brb (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0BRB]):
            yem (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0YEM]):
            ggy (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0GGY]):
            ncl (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0NCL]):
            and_ (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoc
                ationStatsType0AND]):
            sur (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SUR]):
            myt (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MYT]):
            kgz (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0KGZ]):
            bhs (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0BHS]):
            gib (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0GIB]):
            cog (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0COG]):
            fji (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0FJI]):
            blm (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0BLM]):
            cuw (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0CUW]):
            cub (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0CUB]):
            sle (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SLE]):
            blz (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0BLZ]):
            ner (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0NER]):
            lbr (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0LBR]):
            vir (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0VIR]):
            pyf (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0PYF]):
            gum (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0GUM]):
            mrt (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MRT]):
            abw (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ABW]):
            syc (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SYC]):
            guy (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0GUY]):
            lso (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0LSO]):
            swz (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SWZ]):
            ssd (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SSD]):
            lca (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0LCA]):
            mac (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MAC]):
            smr (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SMR]):
            lao (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0LAO]):
            brn (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0BRN]):
            tcd (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0TCD]):
            bmu (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0BMU]):
            vgb (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0VGB]):
            prk (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0PRK]):
            btn (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0BTN]):
            bdi (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0BDI]):
            fro (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0FRO]):
            tjk (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0TJK]):
            gmb (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0GMB]):
            stp (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0STP]):
            ant (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ANT]):
            vct (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0VCT]):
            dji (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0DJI]):
            cpv (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0CPV]):
            tkm (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0TKM]):
            atg (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ATG]):
            tca (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0TCA]):
            kna (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0KNA]):
            grd (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0GRD]):
            asm (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ASM]):
            vut (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0VUT]):
            gnq (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0GNQ]):
            grl (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0GRL]):
            sxm (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SXM]):
            mnp (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MNP]):
            com (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0COM]):
            tls (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0TLS]):
            sjm (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SJM]):
            caf (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0CAF]):
            dma (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0DMA]):
            maf (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MAF]):
            wsm (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0WSM]):
            bes (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0BES]):
            mhl (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MHL]):
            aia (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0AIA]):
            ton (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0TON]):
            cok (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0COK]):
            slb (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SLB]):
            spm (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SPM]):
            gnb (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0GNB]):
            ata (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ATA]):
            tuv (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0TUV]):
            ala (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ALA]):
            iot (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0IOT]):
            eri (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ERI]):
            plw (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0PLW]):
            fsm (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0FSM]):
            nru (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0NRU]):
            pcn (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0PCN]):
            flk (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0FLK]):
            msr (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0MSR]):
            vat (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0VAT]):
            kir (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0KIR]):
            shn (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SHN]):
            niu (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0NIU]):
            wlf (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0WLF]):
            hmd (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0HMD]):
            cxr (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0CXR]):
            nfk (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0NFK]):
            atf (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ATF]):
            cck (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0CCK]):
            sgs (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0SGS]):
            bvt (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0BVT]):
            umi (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0UMI]):
            esh (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0ESH]):
            tkl (Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLoca
                tionStatsType0TKL]):
     """

    usa: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0USA'] = UNSET
    gbr: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GBR'] = UNSET
    fra: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FRA'] = UNSET
    ind: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IND'] = UNSET
    bra: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BRA'] = UNSET
    deu: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DEU'] = UNSET
    esp: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ESP'] = UNSET
    can: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CAN'] = UNSET
    aus: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AUS'] = UNSET
    nld: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NLD'] = UNSET
    ita: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ITA'] = UNSET
    zaf: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ZAF'] = UNSET
    bel: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BEL'] = UNSET
    chn: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CHN'] = UNSET
    tur: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TUR'] = UNSET
    mex: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MEX'] = UNSET
    che: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CHE'] = UNSET
    nor: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NOR'] = UNSET
    are: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ARE'] = UNSET
    swe: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SWE'] = UNSET
    pol: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0POL'] = UNSET
    idn: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IDN'] = UNSET
    arg: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ARG'] = UNSET
    prt: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRT'] = UNSET
    col: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COL'] = UNSET
    chl: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CHL'] = UNSET
    pak: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PAK'] = UNSET
    dnk: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DNK'] = UNSET
    jpn: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JPN'] = UNSET
    nga: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NGA'] = UNSET
    sgp: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SGP'] = UNSET
    per: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PER'] = UNSET
    nzl: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NZL'] = UNSET
    aut: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AUT'] = UNSET
    irl: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IRL'] = UNSET
    mys: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MYS'] = UNSET
    bgd: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BGD'] = UNSET
    egy: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0EGY'] = UNSET
    isr: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ISR'] = UNSET
    sau: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SAU'] = UNSET
    phl: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PHL'] = UNSET
    fin: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FIN'] = UNSET
    irn: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IRN'] = UNSET
    rou: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ROU'] = UNSET
    cze: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CZE'] = UNSET
    grc: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GRC'] = UNSET
    hkg: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HKG'] = UNSET
    hun: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HUN'] = UNSET
    ken: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KEN'] = UNSET
    mar: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MAR'] = UNSET
    vnm: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VNM'] = UNSET
    rus: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0RUS'] = UNSET
    ukr: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UKR'] = UNSET
    ecu: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ECU'] = UNSET
    tha: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0THA'] = UNSET
    lka: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LKA'] = UNSET
    kor: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KOR'] = UNSET
    bgr: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BGR'] = UNSET
    gha: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GHA'] = UNSET
    srb: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SRB'] = UNSET
    twn: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TWN'] = UNSET
    hrv: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HRV'] = UNSET
    ltu: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LTU'] = UNSET
    pri: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRI'] = UNSET
    svk: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SVK'] = UNSET
    tun: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TUN'] = UNSET
    est: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0EST'] = UNSET
    ven: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VEN'] = UNSET
    cri: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CRI'] = UNSET
    pan: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PAN'] = UNSET
    ury: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0URY'] = UNSET
    lbn: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LBN'] = UNSET
    lux: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LUX'] = UNSET
    cyp: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CYP'] = UNSET
    npl: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NPL'] = UNSET
    jor: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JOR'] = UNSET
    svn: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SVN'] = UNSET
    mtq: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MTQ'] = UNSET
    qat: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0QAT'] = UNSET
    glp: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GLP'] = UNSET
    uga: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UGA'] = UNSET
    dza: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DZA'] = UNSET
    gtm: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GTM'] = UNSET
    cmr: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CMR'] = UNSET
    lva: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LVA'] = UNSET
    dom: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DOM'] = UNSET
    aze: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AZE'] = UNSET
    geo: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GEO'] = UNSET
    sen: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SEN'] = UNSET
    tza: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TZA'] = UNSET
    zwe: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ZWE'] = UNSET
    kwt: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KWT'] = UNSET
    mlt: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MLT'] = UNSET
    omn: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0OMN'] = UNSET
    bol: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BOL'] = UNSET
    slv: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SLV'] = UNSET
    arm: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ARM'] = UNSET
    pry: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRY'] = UNSET
    irq: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IRQ'] = UNSET
    khm: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KHM'] = UNSET
    bih: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BIH'] = UNSET
    ago: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AGO'] = UNSET
    bhr: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BHR'] = UNSET
    alb: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ALB'] = UNSET
    kaz: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KAZ'] = UNSET
    civ: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CIV'] = UNSET
    eth: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ETH'] = UNSET
    mus: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MUS'] = UNSET
    zmb: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ZMB'] = UNSET
    mkd: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MKD'] = UNSET
    cod: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COD'] = UNSET
    blr: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BLR'] = UNSET
    moz: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MOZ'] = UNSET
    reu: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0REU'] = UNSET
    tto: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TTO'] = UNSET
    guf: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GUF'] = UNSET
    isl: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ISL'] = UNSET
    mmr: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MMR'] = UNSET
    hnd: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HND'] = UNSET
    rwa: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0RWA'] = UNSET
    mdg: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MDG'] = UNSET
    ben: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BEN'] = UNSET
    uzb: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UZB'] = UNSET
    nam: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NAM'] = UNSET
    bwa: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BWA'] = UNSET
    mda: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MDA'] = UNSET
    jey: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JEY'] = UNSET
    nic: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NIC'] = UNSET
    sdn: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SDN'] = UNSET
    jam: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JAM'] = UNSET
    imn: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IMN'] = UNSET
    bfa: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BFA'] = UNSET
    mng: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MNG'] = UNSET
    mne: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MNE'] = UNSET
    mco: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MCO'] = UNSET
    tgo: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TGO'] = UNSET
    afg: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AFG'] = UNSET
    lby: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LBY'] = UNSET
    xkx: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0XKX'] = UNSET
    cym: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CYM'] = UNSET
    mwi: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MWI'] = UNSET
    som: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SOM'] = UNSET
    png: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PNG'] = UNSET
    mdv: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MDV'] = UNSET
    mli: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MLI'] = UNSET
    gin: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GIN'] = UNSET
    pse: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PSE'] = UNSET
    gab: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GAB'] = UNSET
    lie: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LIE'] = UNSET
    hti: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HTI'] = UNSET
    syr: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SYR'] = UNSET
    brb: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BRB'] = UNSET
    yem: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0YEM'] = UNSET
    ggy: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GGY'] = UNSET
    ncl: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NCL'] = UNSET
    and_: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AND'] = UNSET
    sur: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SUR'] = UNSET
    myt: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MYT'] = UNSET
    kgz: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KGZ'] = UNSET
    bhs: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BHS'] = UNSET
    gib: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GIB'] = UNSET
    cog: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COG'] = UNSET
    fji: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FJI'] = UNSET
    blm: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BLM'] = UNSET
    cuw: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CUW'] = UNSET
    cub: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CUB'] = UNSET
    sle: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SLE'] = UNSET
    blz: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BLZ'] = UNSET
    ner: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NER'] = UNSET
    lbr: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LBR'] = UNSET
    vir: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VIR'] = UNSET
    pyf: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PYF'] = UNSET
    gum: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GUM'] = UNSET
    mrt: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MRT'] = UNSET
    abw: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ABW'] = UNSET
    syc: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SYC'] = UNSET
    guy: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GUY'] = UNSET
    lso: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LSO'] = UNSET
    swz: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SWZ'] = UNSET
    ssd: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SSD'] = UNSET
    lca: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LCA'] = UNSET
    mac: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MAC'] = UNSET
    smr: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SMR'] = UNSET
    lao: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LAO'] = UNSET
    brn: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BRN'] = UNSET
    tcd: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TCD'] = UNSET
    bmu: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BMU'] = UNSET
    vgb: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VGB'] = UNSET
    prk: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRK'] = UNSET
    btn: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BTN'] = UNSET
    bdi: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BDI'] = UNSET
    fro: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FRO'] = UNSET
    tjk: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TJK'] = UNSET
    gmb: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GMB'] = UNSET
    stp: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0STP'] = UNSET
    ant: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ANT'] = UNSET
    vct: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VCT'] = UNSET
    dji: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DJI'] = UNSET
    cpv: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CPV'] = UNSET
    tkm: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TKM'] = UNSET
    atg: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ATG'] = UNSET
    tca: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TCA'] = UNSET
    kna: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KNA'] = UNSET
    grd: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GRD'] = UNSET
    asm: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ASM'] = UNSET
    vut: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VUT'] = UNSET
    gnq: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GNQ'] = UNSET
    grl: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GRL'] = UNSET
    sxm: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SXM'] = UNSET
    mnp: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MNP'] = UNSET
    com: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COM'] = UNSET
    tls: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TLS'] = UNSET
    sjm: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SJM'] = UNSET
    caf: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CAF'] = UNSET
    dma: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DMA'] = UNSET
    maf: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MAF'] = UNSET
    wsm: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0WSM'] = UNSET
    bes: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BES'] = UNSET
    mhl: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MHL'] = UNSET
    aia: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AIA'] = UNSET
    ton: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TON'] = UNSET
    cok: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COK'] = UNSET
    slb: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SLB'] = UNSET
    spm: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SPM'] = UNSET
    gnb: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GNB'] = UNSET
    ata: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ATA'] = UNSET
    tuv: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TUV'] = UNSET
    ala: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ALA'] = UNSET
    iot: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IOT'] = UNSET
    eri: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ERI'] = UNSET
    plw: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PLW'] = UNSET
    fsm: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FSM'] = UNSET
    nru: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NRU'] = UNSET
    pcn: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PCN'] = UNSET
    flk: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FLK'] = UNSET
    msr: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MSR'] = UNSET
    vat: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VAT'] = UNSET
    kir: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KIR'] = UNSET
    shn: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SHN'] = UNSET
    niu: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NIU'] = UNSET
    wlf: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0WLF'] = UNSET
    hmd: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HMD'] = UNSET
    cxr: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CXR'] = UNSET
    nfk: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NFK'] = UNSET
    atf: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ATF'] = UNSET
    cck: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CCK'] = UNSET
    sgs: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SGS'] = UNSET
    bvt: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BVT'] = UNSET
    umi: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UMI'] = UNSET
    esh: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ESH'] = UNSET
    tkl: Union[Unset, 'GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TKL'] = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0aze import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AZE
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0hkg import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HKG
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lbn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LBN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sur import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SUR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mhl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MHL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0hnd import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HND
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lca import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LCA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0brb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BRB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gib import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GIB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pol import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0POL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0kor import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KOR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mmr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MMR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mus import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MUS
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0asm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ASM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gha import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GHA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0slv import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SLV
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bra import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BRA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0rwa import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0RWA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0npl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NPL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0kaz import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KAZ
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0myt import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MYT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0isr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ISR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0fro import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FRO
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0chl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CHL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tgo import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TGO
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ala import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ALA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sau import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SAU
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ind import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IND
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0uzb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UZB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bhs import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BHS
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0vct import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VCT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0flk import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FLK
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0umi import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UMI
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mlt import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MLT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0blz import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BLZ
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0arg import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ARG
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tjk import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TJK
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pry import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRY
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mar import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MAR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mne import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MNE
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0som import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SOM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gbr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GBR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sgs import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SGS
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0prt import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0isl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ISL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sen import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SEN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0geo import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GEO
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0reu import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0REU
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gin import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GIN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sdn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SDN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bgd import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BGD
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0jey import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JEY
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sle import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SLE
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ven import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VEN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0vir import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VIR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sjm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SJM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0rou import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ROU
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0irl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IRL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0xkx import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0XKX
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0are import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ARE
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ant import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ANT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0phl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PHL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nzl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NZL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nic import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NIC
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0svk import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SVK
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0grd import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GRD
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0civ import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CIV
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bel import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BEL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0kir import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KIR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0aia import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AIA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0slb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SLB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0hrv import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HRV
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0zmb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ZMB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0caf import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CAF
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ssd import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SSD
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0swz import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SWZ
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ben import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BEN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mwi import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MWI
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0niu import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NIU
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mac import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MAC
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cck import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CCK
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0dza import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DZA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tza import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TZA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nam import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NAM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0vat import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VAT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0dom import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DOM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tkl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TKL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0blm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BLM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0eri import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ERI
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0svn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SVN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0jam import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JAM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0imn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IMN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nfk import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NFK
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0chn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CHN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cmr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CMR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0usa import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0USA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bih import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BIH
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mkd import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MKD
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bfa import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BFA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tur import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TUR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0srb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SRB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lux import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LUX
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cog import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COG
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0guy import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GUY
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tls import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TLS
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0est import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0EST
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0dma import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DMA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bes import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BES
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nld import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NLD
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0irn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IRN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bdi import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BDI
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0dji import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DJI
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0dnk import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DNK
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0glp import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GLP
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0and import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AND
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mli import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MLI
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cok import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COK
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0plw import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PLW
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mnp import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MNP
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cri import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CRI
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lka import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LKA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gnb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GNB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ken import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KEN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0prk import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRK
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0fin import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FIN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0idn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IDN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gum import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GUM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gnq import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GNQ
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pcn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PCN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tha import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0THA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tun import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TUN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ata import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ATA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0grc import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GRC
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0kwt import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KWT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cpv import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CPV
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gtm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GTM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0twn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TWN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mda import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MDA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pak import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PAK
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nru import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NRU
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0aut import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AUT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0aus import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AUS
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0can import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CAN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0jpn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JPN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0syr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SYR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0msr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MSR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0spm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SPM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0eth import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ETH
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0brn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BRN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lie import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LIE
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0maf import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MAF
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0afg import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AFG
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tto import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TTO
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0zaf import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ZAF
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bmu import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BMU
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lso import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LSO
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mtq import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MTQ
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0kna import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KNA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cxr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CXR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bwa import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BWA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0rus import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0RUS
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bvt import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BVT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ltu import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LTU
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mex import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MEX
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tcd import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TCD
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pan import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PAN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ago import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AGO
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ita import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ITA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lby import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LBY
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mrt import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MRT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0esp import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ESP
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0vnm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VNM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0omn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0OMN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0per import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PER
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0atg import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ATG
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0uga import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UGA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mng import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MNG
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0abw import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ABW
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0hun import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HUN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bol import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BOL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cym import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CYM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nga import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NGA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lbr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LBR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0che import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CHE
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0irq import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IRQ
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0col import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0alb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ALB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0smr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SMR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0jor import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JOR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0btn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BTN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0fra import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FRA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0hti import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HTI
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0hmd import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HMD
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sxm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SXM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tuv import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TUV
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0fsm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FSM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0blr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BLR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0png import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PNG
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bgr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BGR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lao import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LAO
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gmb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GMB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pyf import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PYF
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cyp import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CYP
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0khm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KHM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mdg import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MDG
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mdv import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MDV
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lva import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LVA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mys import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MYS
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cod import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COD
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nor import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NOR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0grl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GRL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0egy import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0EGY
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0iot import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IOT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0com import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ner import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NER
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cze import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CZE
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0zwe import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ZWE
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0moz import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MOZ
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tkm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TKM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ury import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0URY
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cub import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CUB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0syc import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SYC
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ton import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TON
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0yem import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0YEM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0guf import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GUF
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0wlf import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0WLF
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0kgz import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KGZ
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cuw import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CUW
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0vut import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VUT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0fji import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FJI
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sgp import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SGP
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0shn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SHN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0atf import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ATF
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gab import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GAB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mco import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MCO
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pse import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PSE
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0swe import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SWE
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0qat import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0QAT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pri import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRI
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0vgb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VGB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ggy import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GGY
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ecu import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ECU
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ukr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UKR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0wsm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0WSM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0deu import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DEU
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0esh import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ESH
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ncl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NCL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bhr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BHR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0arm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ARM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tca import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TCA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0stp import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0STP
        usa: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.usa, Unset):
            usa = self.usa.to_dict()

        gbr: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.gbr, Unset):
            gbr = self.gbr.to_dict()

        fra: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fra, Unset):
            fra = self.fra.to_dict()

        ind: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.ind, Unset):
            ind = self.ind.to_dict()

        bra: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.bra, Unset):
            bra = self.bra.to_dict()

        deu: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.deu, Unset):
            deu = self.deu.to_dict()

        esp: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.esp, Unset):
            esp = self.esp.to_dict()

        can: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.can, Unset):
            can = self.can.to_dict()

        aus: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.aus, Unset):
            aus = self.aus.to_dict()

        nld: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.nld, Unset):
            nld = self.nld.to_dict()

        ita: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.ita, Unset):
            ita = self.ita.to_dict()

        zaf: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.zaf, Unset):
            zaf = self.zaf.to_dict()

        bel: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.bel, Unset):
            bel = self.bel.to_dict()

        chn: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.chn, Unset):
            chn = self.chn.to_dict()

        tur: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.tur, Unset):
            tur = self.tur.to_dict()

        mex: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mex, Unset):
            mex = self.mex.to_dict()

        che: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.che, Unset):
            che = self.che.to_dict()

        nor: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.nor, Unset):
            nor = self.nor.to_dict()

        are: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.are, Unset):
            are = self.are.to_dict()

        swe: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.swe, Unset):
            swe = self.swe.to_dict()

        pol: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.pol, Unset):
            pol = self.pol.to_dict()

        idn: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.idn, Unset):
            idn = self.idn.to_dict()

        arg: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.arg, Unset):
            arg = self.arg.to_dict()

        prt: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.prt, Unset):
            prt = self.prt.to_dict()

        col: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.col, Unset):
            col = self.col.to_dict()

        chl: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.chl, Unset):
            chl = self.chl.to_dict()

        pak: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.pak, Unset):
            pak = self.pak.to_dict()

        dnk: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.dnk, Unset):
            dnk = self.dnk.to_dict()

        jpn: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.jpn, Unset):
            jpn = self.jpn.to_dict()

        nga: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.nga, Unset):
            nga = self.nga.to_dict()

        sgp: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.sgp, Unset):
            sgp = self.sgp.to_dict()

        per: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.per, Unset):
            per = self.per.to_dict()

        nzl: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.nzl, Unset):
            nzl = self.nzl.to_dict()

        aut: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.aut, Unset):
            aut = self.aut.to_dict()

        irl: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.irl, Unset):
            irl = self.irl.to_dict()

        mys: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mys, Unset):
            mys = self.mys.to_dict()

        bgd: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.bgd, Unset):
            bgd = self.bgd.to_dict()

        egy: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.egy, Unset):
            egy = self.egy.to_dict()

        isr: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.isr, Unset):
            isr = self.isr.to_dict()

        sau: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.sau, Unset):
            sau = self.sau.to_dict()

        phl: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.phl, Unset):
            phl = self.phl.to_dict()

        fin: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fin, Unset):
            fin = self.fin.to_dict()

        irn: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.irn, Unset):
            irn = self.irn.to_dict()

        rou: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.rou, Unset):
            rou = self.rou.to_dict()

        cze: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.cze, Unset):
            cze = self.cze.to_dict()

        grc: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.grc, Unset):
            grc = self.grc.to_dict()

        hkg: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.hkg, Unset):
            hkg = self.hkg.to_dict()

        hun: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.hun, Unset):
            hun = self.hun.to_dict()

        ken: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.ken, Unset):
            ken = self.ken.to_dict()

        mar: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mar, Unset):
            mar = self.mar.to_dict()

        vnm: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.vnm, Unset):
            vnm = self.vnm.to_dict()

        rus: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.rus, Unset):
            rus = self.rus.to_dict()

        ukr: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.ukr, Unset):
            ukr = self.ukr.to_dict()

        ecu: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.ecu, Unset):
            ecu = self.ecu.to_dict()

        tha: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.tha, Unset):
            tha = self.tha.to_dict()

        lka: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.lka, Unset):
            lka = self.lka.to_dict()

        kor: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.kor, Unset):
            kor = self.kor.to_dict()

        bgr: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.bgr, Unset):
            bgr = self.bgr.to_dict()

        gha: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.gha, Unset):
            gha = self.gha.to_dict()

        srb: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.srb, Unset):
            srb = self.srb.to_dict()

        twn: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.twn, Unset):
            twn = self.twn.to_dict()

        hrv: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.hrv, Unset):
            hrv = self.hrv.to_dict()

        ltu: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.ltu, Unset):
            ltu = self.ltu.to_dict()

        pri: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.pri, Unset):
            pri = self.pri.to_dict()

        svk: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.svk, Unset):
            svk = self.svk.to_dict()

        tun: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.tun, Unset):
            tun = self.tun.to_dict()

        est: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.est, Unset):
            est = self.est.to_dict()

        ven: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.ven, Unset):
            ven = self.ven.to_dict()

        cri: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.cri, Unset):
            cri = self.cri.to_dict()

        pan: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.pan, Unset):
            pan = self.pan.to_dict()

        ury: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.ury, Unset):
            ury = self.ury.to_dict()

        lbn: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.lbn, Unset):
            lbn = self.lbn.to_dict()

        lux: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.lux, Unset):
            lux = self.lux.to_dict()

        cyp: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.cyp, Unset):
            cyp = self.cyp.to_dict()

        npl: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.npl, Unset):
            npl = self.npl.to_dict()

        jor: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.jor, Unset):
            jor = self.jor.to_dict()

        svn: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.svn, Unset):
            svn = self.svn.to_dict()

        mtq: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mtq, Unset):
            mtq = self.mtq.to_dict()

        qat: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.qat, Unset):
            qat = self.qat.to_dict()

        glp: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.glp, Unset):
            glp = self.glp.to_dict()

        uga: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.uga, Unset):
            uga = self.uga.to_dict()

        dza: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.dza, Unset):
            dza = self.dza.to_dict()

        gtm: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.gtm, Unset):
            gtm = self.gtm.to_dict()

        cmr: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.cmr, Unset):
            cmr = self.cmr.to_dict()

        lva: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.lva, Unset):
            lva = self.lva.to_dict()

        dom: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.dom, Unset):
            dom = self.dom.to_dict()

        aze: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.aze, Unset):
            aze = self.aze.to_dict()

        geo: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.geo, Unset):
            geo = self.geo.to_dict()

        sen: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.sen, Unset):
            sen = self.sen.to_dict()

        tza: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.tza, Unset):
            tza = self.tza.to_dict()

        zwe: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.zwe, Unset):
            zwe = self.zwe.to_dict()

        kwt: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.kwt, Unset):
            kwt = self.kwt.to_dict()

        mlt: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mlt, Unset):
            mlt = self.mlt.to_dict()

        omn: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.omn, Unset):
            omn = self.omn.to_dict()

        bol: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.bol, Unset):
            bol = self.bol.to_dict()

        slv: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.slv, Unset):
            slv = self.slv.to_dict()

        arm: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.arm, Unset):
            arm = self.arm.to_dict()

        pry: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.pry, Unset):
            pry = self.pry.to_dict()

        irq: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.irq, Unset):
            irq = self.irq.to_dict()

        khm: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.khm, Unset):
            khm = self.khm.to_dict()

        bih: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.bih, Unset):
            bih = self.bih.to_dict()

        ago: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.ago, Unset):
            ago = self.ago.to_dict()

        bhr: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.bhr, Unset):
            bhr = self.bhr.to_dict()

        alb: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.alb, Unset):
            alb = self.alb.to_dict()

        kaz: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.kaz, Unset):
            kaz = self.kaz.to_dict()

        civ: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.civ, Unset):
            civ = self.civ.to_dict()

        eth: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.eth, Unset):
            eth = self.eth.to_dict()

        mus: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mus, Unset):
            mus = self.mus.to_dict()

        zmb: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.zmb, Unset):
            zmb = self.zmb.to_dict()

        mkd: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mkd, Unset):
            mkd = self.mkd.to_dict()

        cod: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.cod, Unset):
            cod = self.cod.to_dict()

        blr: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.blr, Unset):
            blr = self.blr.to_dict()

        moz: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.moz, Unset):
            moz = self.moz.to_dict()

        reu: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.reu, Unset):
            reu = self.reu.to_dict()

        tto: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.tto, Unset):
            tto = self.tto.to_dict()

        guf: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.guf, Unset):
            guf = self.guf.to_dict()

        isl: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.isl, Unset):
            isl = self.isl.to_dict()

        mmr: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mmr, Unset):
            mmr = self.mmr.to_dict()

        hnd: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.hnd, Unset):
            hnd = self.hnd.to_dict()

        rwa: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.rwa, Unset):
            rwa = self.rwa.to_dict()

        mdg: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mdg, Unset):
            mdg = self.mdg.to_dict()

        ben: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.ben, Unset):
            ben = self.ben.to_dict()

        uzb: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.uzb, Unset):
            uzb = self.uzb.to_dict()

        nam: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.nam, Unset):
            nam = self.nam.to_dict()

        bwa: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.bwa, Unset):
            bwa = self.bwa.to_dict()

        mda: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mda, Unset):
            mda = self.mda.to_dict()

        jey: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.jey, Unset):
            jey = self.jey.to_dict()

        nic: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.nic, Unset):
            nic = self.nic.to_dict()

        sdn: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.sdn, Unset):
            sdn = self.sdn.to_dict()

        jam: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.jam, Unset):
            jam = self.jam.to_dict()

        imn: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.imn, Unset):
            imn = self.imn.to_dict()

        bfa: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.bfa, Unset):
            bfa = self.bfa.to_dict()

        mng: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mng, Unset):
            mng = self.mng.to_dict()

        mne: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mne, Unset):
            mne = self.mne.to_dict()

        mco: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mco, Unset):
            mco = self.mco.to_dict()

        tgo: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.tgo, Unset):
            tgo = self.tgo.to_dict()

        afg: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.afg, Unset):
            afg = self.afg.to_dict()

        lby: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.lby, Unset):
            lby = self.lby.to_dict()

        xkx: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.xkx, Unset):
            xkx = self.xkx.to_dict()

        cym: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.cym, Unset):
            cym = self.cym.to_dict()

        mwi: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mwi, Unset):
            mwi = self.mwi.to_dict()

        som: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.som, Unset):
            som = self.som.to_dict()

        png: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.png, Unset):
            png = self.png.to_dict()

        mdv: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mdv, Unset):
            mdv = self.mdv.to_dict()

        mli: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mli, Unset):
            mli = self.mli.to_dict()

        gin: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.gin, Unset):
            gin = self.gin.to_dict()

        pse: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.pse, Unset):
            pse = self.pse.to_dict()

        gab: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.gab, Unset):
            gab = self.gab.to_dict()

        lie: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.lie, Unset):
            lie = self.lie.to_dict()

        hti: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.hti, Unset):
            hti = self.hti.to_dict()

        syr: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.syr, Unset):
            syr = self.syr.to_dict()

        brb: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.brb, Unset):
            brb = self.brb.to_dict()

        yem: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.yem, Unset):
            yem = self.yem.to_dict()

        ggy: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.ggy, Unset):
            ggy = self.ggy.to_dict()

        ncl: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.ncl, Unset):
            ncl = self.ncl.to_dict()

        and_: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.and_, Unset):
            and_ = self.and_.to_dict()

        sur: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.sur, Unset):
            sur = self.sur.to_dict()

        myt: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.myt, Unset):
            myt = self.myt.to_dict()

        kgz: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.kgz, Unset):
            kgz = self.kgz.to_dict()

        bhs: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.bhs, Unset):
            bhs = self.bhs.to_dict()

        gib: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.gib, Unset):
            gib = self.gib.to_dict()

        cog: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.cog, Unset):
            cog = self.cog.to_dict()

        fji: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fji, Unset):
            fji = self.fji.to_dict()

        blm: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.blm, Unset):
            blm = self.blm.to_dict()

        cuw: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.cuw, Unset):
            cuw = self.cuw.to_dict()

        cub: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.cub, Unset):
            cub = self.cub.to_dict()

        sle: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.sle, Unset):
            sle = self.sle.to_dict()

        blz: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.blz, Unset):
            blz = self.blz.to_dict()

        ner: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.ner, Unset):
            ner = self.ner.to_dict()

        lbr: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.lbr, Unset):
            lbr = self.lbr.to_dict()

        vir: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.vir, Unset):
            vir = self.vir.to_dict()

        pyf: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.pyf, Unset):
            pyf = self.pyf.to_dict()

        gum: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.gum, Unset):
            gum = self.gum.to_dict()

        mrt: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mrt, Unset):
            mrt = self.mrt.to_dict()

        abw: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.abw, Unset):
            abw = self.abw.to_dict()

        syc: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.syc, Unset):
            syc = self.syc.to_dict()

        guy: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.guy, Unset):
            guy = self.guy.to_dict()

        lso: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.lso, Unset):
            lso = self.lso.to_dict()

        swz: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.swz, Unset):
            swz = self.swz.to_dict()

        ssd: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.ssd, Unset):
            ssd = self.ssd.to_dict()

        lca: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.lca, Unset):
            lca = self.lca.to_dict()

        mac: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mac, Unset):
            mac = self.mac.to_dict()

        smr: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.smr, Unset):
            smr = self.smr.to_dict()

        lao: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.lao, Unset):
            lao = self.lao.to_dict()

        brn: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.brn, Unset):
            brn = self.brn.to_dict()

        tcd: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.tcd, Unset):
            tcd = self.tcd.to_dict()

        bmu: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.bmu, Unset):
            bmu = self.bmu.to_dict()

        vgb: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.vgb, Unset):
            vgb = self.vgb.to_dict()

        prk: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.prk, Unset):
            prk = self.prk.to_dict()

        btn: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.btn, Unset):
            btn = self.btn.to_dict()

        bdi: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.bdi, Unset):
            bdi = self.bdi.to_dict()

        fro: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fro, Unset):
            fro = self.fro.to_dict()

        tjk: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.tjk, Unset):
            tjk = self.tjk.to_dict()

        gmb: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.gmb, Unset):
            gmb = self.gmb.to_dict()

        stp: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.stp, Unset):
            stp = self.stp.to_dict()

        ant: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.ant, Unset):
            ant = self.ant.to_dict()

        vct: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.vct, Unset):
            vct = self.vct.to_dict()

        dji: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.dji, Unset):
            dji = self.dji.to_dict()

        cpv: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.cpv, Unset):
            cpv = self.cpv.to_dict()

        tkm: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.tkm, Unset):
            tkm = self.tkm.to_dict()

        atg: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.atg, Unset):
            atg = self.atg.to_dict()

        tca: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.tca, Unset):
            tca = self.tca.to_dict()

        kna: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.kna, Unset):
            kna = self.kna.to_dict()

        grd: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.grd, Unset):
            grd = self.grd.to_dict()

        asm: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.asm, Unset):
            asm = self.asm.to_dict()

        vut: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.vut, Unset):
            vut = self.vut.to_dict()

        gnq: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.gnq, Unset):
            gnq = self.gnq.to_dict()

        grl: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.grl, Unset):
            grl = self.grl.to_dict()

        sxm: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.sxm, Unset):
            sxm = self.sxm.to_dict()

        mnp: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mnp, Unset):
            mnp = self.mnp.to_dict()

        com: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.com, Unset):
            com = self.com.to_dict()

        tls: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.tls, Unset):
            tls = self.tls.to_dict()

        sjm: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.sjm, Unset):
            sjm = self.sjm.to_dict()

        caf: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.caf, Unset):
            caf = self.caf.to_dict()

        dma: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.dma, Unset):
            dma = self.dma.to_dict()

        maf: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.maf, Unset):
            maf = self.maf.to_dict()

        wsm: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.wsm, Unset):
            wsm = self.wsm.to_dict()

        bes: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.bes, Unset):
            bes = self.bes.to_dict()

        mhl: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.mhl, Unset):
            mhl = self.mhl.to_dict()

        aia: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.aia, Unset):
            aia = self.aia.to_dict()

        ton: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.ton, Unset):
            ton = self.ton.to_dict()

        cok: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.cok, Unset):
            cok = self.cok.to_dict()

        slb: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.slb, Unset):
            slb = self.slb.to_dict()

        spm: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.spm, Unset):
            spm = self.spm.to_dict()

        gnb: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.gnb, Unset):
            gnb = self.gnb.to_dict()

        ata: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.ata, Unset):
            ata = self.ata.to_dict()

        tuv: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.tuv, Unset):
            tuv = self.tuv.to_dict()

        ala: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.ala, Unset):
            ala = self.ala.to_dict()

        iot: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.iot, Unset):
            iot = self.iot.to_dict()

        eri: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.eri, Unset):
            eri = self.eri.to_dict()

        plw: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.plw, Unset):
            plw = self.plw.to_dict()

        fsm: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.fsm, Unset):
            fsm = self.fsm.to_dict()

        nru: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.nru, Unset):
            nru = self.nru.to_dict()

        pcn: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.pcn, Unset):
            pcn = self.pcn.to_dict()

        flk: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.flk, Unset):
            flk = self.flk.to_dict()

        msr: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.msr, Unset):
            msr = self.msr.to_dict()

        vat: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.vat, Unset):
            vat = self.vat.to_dict()

        kir: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.kir, Unset):
            kir = self.kir.to_dict()

        shn: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.shn, Unset):
            shn = self.shn.to_dict()

        niu: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.niu, Unset):
            niu = self.niu.to_dict()

        wlf: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.wlf, Unset):
            wlf = self.wlf.to_dict()

        hmd: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.hmd, Unset):
            hmd = self.hmd.to_dict()

        cxr: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.cxr, Unset):
            cxr = self.cxr.to_dict()

        nfk: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.nfk, Unset):
            nfk = self.nfk.to_dict()

        atf: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.atf, Unset):
            atf = self.atf.to_dict()

        cck: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.cck, Unset):
            cck = self.cck.to_dict()

        sgs: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.sgs, Unset):
            sgs = self.sgs.to_dict()

        bvt: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.bvt, Unset):
            bvt = self.bvt.to_dict()

        umi: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.umi, Unset):
            umi = self.umi.to_dict()

        esh: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.esh, Unset):
            esh = self.esh.to_dict()

        tkl: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.tkl, Unset):
            tkl = self.tkl.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
        })
        if usa is not UNSET:
            field_dict["USA"] = usa
        if gbr is not UNSET:
            field_dict["GBR"] = gbr
        if fra is not UNSET:
            field_dict["FRA"] = fra
        if ind is not UNSET:
            field_dict["IND"] = ind
        if bra is not UNSET:
            field_dict["BRA"] = bra
        if deu is not UNSET:
            field_dict["DEU"] = deu
        if esp is not UNSET:
            field_dict["ESP"] = esp
        if can is not UNSET:
            field_dict["CAN"] = can
        if aus is not UNSET:
            field_dict["AUS"] = aus
        if nld is not UNSET:
            field_dict["NLD"] = nld
        if ita is not UNSET:
            field_dict["ITA"] = ita
        if zaf is not UNSET:
            field_dict["ZAF"] = zaf
        if bel is not UNSET:
            field_dict["BEL"] = bel
        if chn is not UNSET:
            field_dict["CHN"] = chn
        if tur is not UNSET:
            field_dict["TUR"] = tur
        if mex is not UNSET:
            field_dict["MEX"] = mex
        if che is not UNSET:
            field_dict["CHE"] = che
        if nor is not UNSET:
            field_dict["NOR"] = nor
        if are is not UNSET:
            field_dict["ARE"] = are
        if swe is not UNSET:
            field_dict["SWE"] = swe
        if pol is not UNSET:
            field_dict["POL"] = pol
        if idn is not UNSET:
            field_dict["IDN"] = idn
        if arg is not UNSET:
            field_dict["ARG"] = arg
        if prt is not UNSET:
            field_dict["PRT"] = prt
        if col is not UNSET:
            field_dict["COL"] = col
        if chl is not UNSET:
            field_dict["CHL"] = chl
        if pak is not UNSET:
            field_dict["PAK"] = pak
        if dnk is not UNSET:
            field_dict["DNK"] = dnk
        if jpn is not UNSET:
            field_dict["JPN"] = jpn
        if nga is not UNSET:
            field_dict["NGA"] = nga
        if sgp is not UNSET:
            field_dict["SGP"] = sgp
        if per is not UNSET:
            field_dict["PER"] = per
        if nzl is not UNSET:
            field_dict["NZL"] = nzl
        if aut is not UNSET:
            field_dict["AUT"] = aut
        if irl is not UNSET:
            field_dict["IRL"] = irl
        if mys is not UNSET:
            field_dict["MYS"] = mys
        if bgd is not UNSET:
            field_dict["BGD"] = bgd
        if egy is not UNSET:
            field_dict["EGY"] = egy
        if isr is not UNSET:
            field_dict["ISR"] = isr
        if sau is not UNSET:
            field_dict["SAU"] = sau
        if phl is not UNSET:
            field_dict["PHL"] = phl
        if fin is not UNSET:
            field_dict["FIN"] = fin
        if irn is not UNSET:
            field_dict["IRN"] = irn
        if rou is not UNSET:
            field_dict["ROU"] = rou
        if cze is not UNSET:
            field_dict["CZE"] = cze
        if grc is not UNSET:
            field_dict["GRC"] = grc
        if hkg is not UNSET:
            field_dict["HKG"] = hkg
        if hun is not UNSET:
            field_dict["HUN"] = hun
        if ken is not UNSET:
            field_dict["KEN"] = ken
        if mar is not UNSET:
            field_dict["MAR"] = mar
        if vnm is not UNSET:
            field_dict["VNM"] = vnm
        if rus is not UNSET:
            field_dict["RUS"] = rus
        if ukr is not UNSET:
            field_dict["UKR"] = ukr
        if ecu is not UNSET:
            field_dict["ECU"] = ecu
        if tha is not UNSET:
            field_dict["THA"] = tha
        if lka is not UNSET:
            field_dict["LKA"] = lka
        if kor is not UNSET:
            field_dict["KOR"] = kor
        if bgr is not UNSET:
            field_dict["BGR"] = bgr
        if gha is not UNSET:
            field_dict["GHA"] = gha
        if srb is not UNSET:
            field_dict["SRB"] = srb
        if twn is not UNSET:
            field_dict["TWN"] = twn
        if hrv is not UNSET:
            field_dict["HRV"] = hrv
        if ltu is not UNSET:
            field_dict["LTU"] = ltu
        if pri is not UNSET:
            field_dict["PRI"] = pri
        if svk is not UNSET:
            field_dict["SVK"] = svk
        if tun is not UNSET:
            field_dict["TUN"] = tun
        if est is not UNSET:
            field_dict["EST"] = est
        if ven is not UNSET:
            field_dict["VEN"] = ven
        if cri is not UNSET:
            field_dict["CRI"] = cri
        if pan is not UNSET:
            field_dict["PAN"] = pan
        if ury is not UNSET:
            field_dict["URY"] = ury
        if lbn is not UNSET:
            field_dict["LBN"] = lbn
        if lux is not UNSET:
            field_dict["LUX"] = lux
        if cyp is not UNSET:
            field_dict["CYP"] = cyp
        if npl is not UNSET:
            field_dict["NPL"] = npl
        if jor is not UNSET:
            field_dict["JOR"] = jor
        if svn is not UNSET:
            field_dict["SVN"] = svn
        if mtq is not UNSET:
            field_dict["MTQ"] = mtq
        if qat is not UNSET:
            field_dict["QAT"] = qat
        if glp is not UNSET:
            field_dict["GLP"] = glp
        if uga is not UNSET:
            field_dict["UGA"] = uga
        if dza is not UNSET:
            field_dict["DZA"] = dza
        if gtm is not UNSET:
            field_dict["GTM"] = gtm
        if cmr is not UNSET:
            field_dict["CMR"] = cmr
        if lva is not UNSET:
            field_dict["LVA"] = lva
        if dom is not UNSET:
            field_dict["DOM"] = dom
        if aze is not UNSET:
            field_dict["AZE"] = aze
        if geo is not UNSET:
            field_dict["GEO"] = geo
        if sen is not UNSET:
            field_dict["SEN"] = sen
        if tza is not UNSET:
            field_dict["TZA"] = tza
        if zwe is not UNSET:
            field_dict["ZWE"] = zwe
        if kwt is not UNSET:
            field_dict["KWT"] = kwt
        if mlt is not UNSET:
            field_dict["MLT"] = mlt
        if omn is not UNSET:
            field_dict["OMN"] = omn
        if bol is not UNSET:
            field_dict["BOL"] = bol
        if slv is not UNSET:
            field_dict["SLV"] = slv
        if arm is not UNSET:
            field_dict["ARM"] = arm
        if pry is not UNSET:
            field_dict["PRY"] = pry
        if irq is not UNSET:
            field_dict["IRQ"] = irq
        if khm is not UNSET:
            field_dict["KHM"] = khm
        if bih is not UNSET:
            field_dict["BIH"] = bih
        if ago is not UNSET:
            field_dict["AGO"] = ago
        if bhr is not UNSET:
            field_dict["BHR"] = bhr
        if alb is not UNSET:
            field_dict["ALB"] = alb
        if kaz is not UNSET:
            field_dict["KAZ"] = kaz
        if civ is not UNSET:
            field_dict["CIV"] = civ
        if eth is not UNSET:
            field_dict["ETH"] = eth
        if mus is not UNSET:
            field_dict["MUS"] = mus
        if zmb is not UNSET:
            field_dict["ZMB"] = zmb
        if mkd is not UNSET:
            field_dict["MKD"] = mkd
        if cod is not UNSET:
            field_dict["COD"] = cod
        if blr is not UNSET:
            field_dict["BLR"] = blr
        if moz is not UNSET:
            field_dict["MOZ"] = moz
        if reu is not UNSET:
            field_dict["REU"] = reu
        if tto is not UNSET:
            field_dict["TTO"] = tto
        if guf is not UNSET:
            field_dict["GUF"] = guf
        if isl is not UNSET:
            field_dict["ISL"] = isl
        if mmr is not UNSET:
            field_dict["MMR"] = mmr
        if hnd is not UNSET:
            field_dict["HND"] = hnd
        if rwa is not UNSET:
            field_dict["RWA"] = rwa
        if mdg is not UNSET:
            field_dict["MDG"] = mdg
        if ben is not UNSET:
            field_dict["BEN"] = ben
        if uzb is not UNSET:
            field_dict["UZB"] = uzb
        if nam is not UNSET:
            field_dict["NAM"] = nam
        if bwa is not UNSET:
            field_dict["BWA"] = bwa
        if mda is not UNSET:
            field_dict["MDA"] = mda
        if jey is not UNSET:
            field_dict["JEY"] = jey
        if nic is not UNSET:
            field_dict["NIC"] = nic
        if sdn is not UNSET:
            field_dict["SDN"] = sdn
        if jam is not UNSET:
            field_dict["JAM"] = jam
        if imn is not UNSET:
            field_dict["IMN"] = imn
        if bfa is not UNSET:
            field_dict["BFA"] = bfa
        if mng is not UNSET:
            field_dict["MNG"] = mng
        if mne is not UNSET:
            field_dict["MNE"] = mne
        if mco is not UNSET:
            field_dict["MCO"] = mco
        if tgo is not UNSET:
            field_dict["TGO"] = tgo
        if afg is not UNSET:
            field_dict["AFG"] = afg
        if lby is not UNSET:
            field_dict["LBY"] = lby
        if xkx is not UNSET:
            field_dict["XKX"] = xkx
        if cym is not UNSET:
            field_dict["CYM"] = cym
        if mwi is not UNSET:
            field_dict["MWI"] = mwi
        if som is not UNSET:
            field_dict["SOM"] = som
        if png is not UNSET:
            field_dict["PNG"] = png
        if mdv is not UNSET:
            field_dict["MDV"] = mdv
        if mli is not UNSET:
            field_dict["MLI"] = mli
        if gin is not UNSET:
            field_dict["GIN"] = gin
        if pse is not UNSET:
            field_dict["PSE"] = pse
        if gab is not UNSET:
            field_dict["GAB"] = gab
        if lie is not UNSET:
            field_dict["LIE"] = lie
        if hti is not UNSET:
            field_dict["HTI"] = hti
        if syr is not UNSET:
            field_dict["SYR"] = syr
        if brb is not UNSET:
            field_dict["BRB"] = brb
        if yem is not UNSET:
            field_dict["YEM"] = yem
        if ggy is not UNSET:
            field_dict["GGY"] = ggy
        if ncl is not UNSET:
            field_dict["NCL"] = ncl
        if and_ is not UNSET:
            field_dict["AND"] = and_
        if sur is not UNSET:
            field_dict["SUR"] = sur
        if myt is not UNSET:
            field_dict["MYT"] = myt
        if kgz is not UNSET:
            field_dict["KGZ"] = kgz
        if bhs is not UNSET:
            field_dict["BHS"] = bhs
        if gib is not UNSET:
            field_dict["GIB"] = gib
        if cog is not UNSET:
            field_dict["COG"] = cog
        if fji is not UNSET:
            field_dict["FJI"] = fji
        if blm is not UNSET:
            field_dict["BLM"] = blm
        if cuw is not UNSET:
            field_dict["CUW"] = cuw
        if cub is not UNSET:
            field_dict["CUB"] = cub
        if sle is not UNSET:
            field_dict["SLE"] = sle
        if blz is not UNSET:
            field_dict["BLZ"] = blz
        if ner is not UNSET:
            field_dict["NER"] = ner
        if lbr is not UNSET:
            field_dict["LBR"] = lbr
        if vir is not UNSET:
            field_dict["VIR"] = vir
        if pyf is not UNSET:
            field_dict["PYF"] = pyf
        if gum is not UNSET:
            field_dict["GUM"] = gum
        if mrt is not UNSET:
            field_dict["MRT"] = mrt
        if abw is not UNSET:
            field_dict["ABW"] = abw
        if syc is not UNSET:
            field_dict["SYC"] = syc
        if guy is not UNSET:
            field_dict["GUY"] = guy
        if lso is not UNSET:
            field_dict["LSO"] = lso
        if swz is not UNSET:
            field_dict["SWZ"] = swz
        if ssd is not UNSET:
            field_dict["SSD"] = ssd
        if lca is not UNSET:
            field_dict["LCA"] = lca
        if mac is not UNSET:
            field_dict["MAC"] = mac
        if smr is not UNSET:
            field_dict["SMR"] = smr
        if lao is not UNSET:
            field_dict["LAO"] = lao
        if brn is not UNSET:
            field_dict["BRN"] = brn
        if tcd is not UNSET:
            field_dict["TCD"] = tcd
        if bmu is not UNSET:
            field_dict["BMU"] = bmu
        if vgb is not UNSET:
            field_dict["VGB"] = vgb
        if prk is not UNSET:
            field_dict["PRK"] = prk
        if btn is not UNSET:
            field_dict["BTN"] = btn
        if bdi is not UNSET:
            field_dict["BDI"] = bdi
        if fro is not UNSET:
            field_dict["FRO"] = fro
        if tjk is not UNSET:
            field_dict["TJK"] = tjk
        if gmb is not UNSET:
            field_dict["GMB"] = gmb
        if stp is not UNSET:
            field_dict["STP"] = stp
        if ant is not UNSET:
            field_dict["ANT"] = ant
        if vct is not UNSET:
            field_dict["VCT"] = vct
        if dji is not UNSET:
            field_dict["DJI"] = dji
        if cpv is not UNSET:
            field_dict["CPV"] = cpv
        if tkm is not UNSET:
            field_dict["TKM"] = tkm
        if atg is not UNSET:
            field_dict["ATG"] = atg
        if tca is not UNSET:
            field_dict["TCA"] = tca
        if kna is not UNSET:
            field_dict["KNA"] = kna
        if grd is not UNSET:
            field_dict["GRD"] = grd
        if asm is not UNSET:
            field_dict["ASM"] = asm
        if vut is not UNSET:
            field_dict["VUT"] = vut
        if gnq is not UNSET:
            field_dict["GNQ"] = gnq
        if grl is not UNSET:
            field_dict["GRL"] = grl
        if sxm is not UNSET:
            field_dict["SXM"] = sxm
        if mnp is not UNSET:
            field_dict["MNP"] = mnp
        if com is not UNSET:
            field_dict["COM"] = com
        if tls is not UNSET:
            field_dict["TLS"] = tls
        if sjm is not UNSET:
            field_dict["SJM"] = sjm
        if caf is not UNSET:
            field_dict["CAF"] = caf
        if dma is not UNSET:
            field_dict["DMA"] = dma
        if maf is not UNSET:
            field_dict["MAF"] = maf
        if wsm is not UNSET:
            field_dict["WSM"] = wsm
        if bes is not UNSET:
            field_dict["BES"] = bes
        if mhl is not UNSET:
            field_dict["MHL"] = mhl
        if aia is not UNSET:
            field_dict["AIA"] = aia
        if ton is not UNSET:
            field_dict["TON"] = ton
        if cok is not UNSET:
            field_dict["COK"] = cok
        if slb is not UNSET:
            field_dict["SLB"] = slb
        if spm is not UNSET:
            field_dict["SPM"] = spm
        if gnb is not UNSET:
            field_dict["GNB"] = gnb
        if ata is not UNSET:
            field_dict["ATA"] = ata
        if tuv is not UNSET:
            field_dict["TUV"] = tuv
        if ala is not UNSET:
            field_dict["ALA"] = ala
        if iot is not UNSET:
            field_dict["IOT"] = iot
        if eri is not UNSET:
            field_dict["ERI"] = eri
        if plw is not UNSET:
            field_dict["PLW"] = plw
        if fsm is not UNSET:
            field_dict["FSM"] = fsm
        if nru is not UNSET:
            field_dict["NRU"] = nru
        if pcn is not UNSET:
            field_dict["PCN"] = pcn
        if flk is not UNSET:
            field_dict["FLK"] = flk
        if msr is not UNSET:
            field_dict["MSR"] = msr
        if vat is not UNSET:
            field_dict["VAT"] = vat
        if kir is not UNSET:
            field_dict["KIR"] = kir
        if shn is not UNSET:
            field_dict["SHN"] = shn
        if niu is not UNSET:
            field_dict["NIU"] = niu
        if wlf is not UNSET:
            field_dict["WLF"] = wlf
        if hmd is not UNSET:
            field_dict["HMD"] = hmd
        if cxr is not UNSET:
            field_dict["CXR"] = cxr
        if nfk is not UNSET:
            field_dict["NFK"] = nfk
        if atf is not UNSET:
            field_dict["ATF"] = atf
        if cck is not UNSET:
            field_dict["CCK"] = cck
        if sgs is not UNSET:
            field_dict["SGS"] = sgs
        if bvt is not UNSET:
            field_dict["BVT"] = bvt
        if umi is not UNSET:
            field_dict["UMI"] = umi
        if esh is not UNSET:
            field_dict["ESH"] = esh
        if tkl is not UNSET:
            field_dict["TKL"] = tkl

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0aze import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AZE
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0hkg import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HKG
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lbn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LBN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sur import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SUR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mhl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MHL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0hnd import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HND
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lca import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LCA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0brb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BRB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gib import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GIB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pol import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0POL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0kor import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KOR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mmr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MMR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mus import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MUS
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0asm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ASM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gha import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GHA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0slv import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SLV
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bra import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BRA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0rwa import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0RWA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0npl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NPL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0kaz import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KAZ
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0myt import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MYT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0isr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ISR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0fro import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FRO
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0chl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CHL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tgo import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TGO
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ala import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ALA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sau import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SAU
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ind import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IND
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0uzb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UZB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bhs import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BHS
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0vct import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VCT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0flk import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FLK
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0umi import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UMI
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mlt import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MLT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0blz import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BLZ
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0arg import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ARG
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tjk import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TJK
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pry import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRY
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mar import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MAR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mne import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MNE
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0som import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SOM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gbr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GBR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sgs import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SGS
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0prt import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0isl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ISL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sen import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SEN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0geo import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GEO
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0reu import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0REU
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gin import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GIN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sdn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SDN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bgd import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BGD
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0jey import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JEY
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sle import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SLE
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ven import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VEN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0vir import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VIR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sjm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SJM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0rou import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ROU
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0irl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IRL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0xkx import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0XKX
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0are import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ARE
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ant import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ANT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0phl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PHL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nzl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NZL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nic import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NIC
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0svk import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SVK
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0grd import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GRD
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0civ import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CIV
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bel import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BEL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0kir import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KIR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0aia import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AIA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0slb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SLB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0hrv import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HRV
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0zmb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ZMB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0caf import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CAF
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ssd import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SSD
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0swz import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SWZ
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ben import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BEN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mwi import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MWI
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0niu import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NIU
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mac import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MAC
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cck import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CCK
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0dza import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DZA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tza import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TZA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nam import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NAM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0vat import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VAT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0dom import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DOM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tkl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TKL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0blm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BLM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0eri import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ERI
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0svn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SVN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0jam import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JAM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0imn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IMN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nfk import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NFK
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0chn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CHN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cmr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CMR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0usa import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0USA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bih import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BIH
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mkd import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MKD
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bfa import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BFA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tur import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TUR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0srb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SRB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lux import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LUX
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cog import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COG
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0guy import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GUY
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tls import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TLS
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0est import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0EST
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0dma import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DMA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bes import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BES
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nld import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NLD
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0irn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IRN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bdi import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BDI
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0dji import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DJI
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0dnk import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DNK
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0glp import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GLP
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0and import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AND
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mli import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MLI
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cok import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COK
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0plw import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PLW
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mnp import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MNP
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cri import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CRI
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lka import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LKA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gnb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GNB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ken import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KEN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0prk import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRK
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0fin import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FIN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0idn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IDN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gum import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GUM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gnq import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GNQ
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pcn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PCN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tha import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0THA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tun import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TUN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ata import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ATA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0grc import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GRC
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0kwt import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KWT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cpv import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CPV
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gtm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GTM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0twn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TWN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mda import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MDA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pak import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PAK
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nru import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NRU
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0aut import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AUT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0aus import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AUS
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0can import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CAN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0jpn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JPN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0syr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SYR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0msr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MSR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0spm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SPM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0eth import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ETH
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0brn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BRN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lie import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LIE
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0maf import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MAF
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0afg import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AFG
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tto import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TTO
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0zaf import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ZAF
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bmu import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BMU
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lso import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LSO
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mtq import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MTQ
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0kna import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KNA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cxr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CXR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bwa import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BWA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0rus import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0RUS
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bvt import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BVT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ltu import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LTU
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mex import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MEX
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tcd import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TCD
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pan import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PAN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ago import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AGO
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ita import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ITA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lby import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LBY
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mrt import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MRT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0esp import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ESP
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0vnm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VNM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0omn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0OMN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0per import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PER
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0atg import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ATG
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0uga import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UGA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mng import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MNG
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0abw import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ABW
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0hun import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HUN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bol import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BOL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cym import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CYM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nga import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NGA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lbr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LBR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0che import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CHE
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0irq import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IRQ
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0col import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0alb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ALB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0smr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SMR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0jor import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JOR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0btn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BTN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0fra import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FRA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0hti import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HTI
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0hmd import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HMD
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sxm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SXM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tuv import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TUV
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0fsm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FSM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0blr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BLR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0png import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PNG
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bgr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BGR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lao import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LAO
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gmb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GMB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pyf import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PYF
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cyp import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CYP
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0khm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KHM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mdg import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MDG
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mdv import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MDV
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0lva import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LVA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mys import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MYS
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cod import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COD
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0nor import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NOR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0grl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GRL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0egy import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0EGY
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0iot import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IOT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0com import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ner import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NER
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cze import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CZE
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0zwe import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ZWE
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0moz import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MOZ
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tkm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TKM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ury import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0URY
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cub import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CUB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0syc import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SYC
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ton import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TON
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0yem import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0YEM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0guf import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GUF
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0wlf import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0WLF
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0kgz import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KGZ
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0cuw import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CUW
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0vut import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VUT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0fji import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FJI
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0sgp import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SGP
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0shn import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SHN
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0atf import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ATF
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0gab import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GAB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0mco import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MCO
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pse import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PSE
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0swe import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SWE
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0qat import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0QAT
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0pri import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRI
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0vgb import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VGB
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ggy import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GGY
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ecu import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ECU
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ukr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UKR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0wsm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0WSM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0deu import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DEU
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0esh import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ESH
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0ncl import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NCL
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0bhr import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BHR
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0arm import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ARM
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0tca import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TCA
        from ..models.get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0stp import GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0STP
        d = dict(src_dict)
        _usa = d.pop("USA", UNSET)
        usa: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0USA]
        if isinstance(_usa,  Unset):
            usa = UNSET
        else:
            usa = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0USA.from_dict(_usa)




        _gbr = d.pop("GBR", UNSET)
        gbr: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GBR]
        if isinstance(_gbr,  Unset):
            gbr = UNSET
        else:
            gbr = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GBR.from_dict(_gbr)




        _fra = d.pop("FRA", UNSET)
        fra: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FRA]
        if isinstance(_fra,  Unset):
            fra = UNSET
        else:
            fra = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FRA.from_dict(_fra)




        _ind = d.pop("IND", UNSET)
        ind: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IND]
        if isinstance(_ind,  Unset):
            ind = UNSET
        else:
            ind = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IND.from_dict(_ind)




        _bra = d.pop("BRA", UNSET)
        bra: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BRA]
        if isinstance(_bra,  Unset):
            bra = UNSET
        else:
            bra = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BRA.from_dict(_bra)




        _deu = d.pop("DEU", UNSET)
        deu: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DEU]
        if isinstance(_deu,  Unset):
            deu = UNSET
        else:
            deu = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DEU.from_dict(_deu)




        _esp = d.pop("ESP", UNSET)
        esp: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ESP]
        if isinstance(_esp,  Unset):
            esp = UNSET
        else:
            esp = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ESP.from_dict(_esp)




        _can = d.pop("CAN", UNSET)
        can: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CAN]
        if isinstance(_can,  Unset):
            can = UNSET
        else:
            can = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CAN.from_dict(_can)




        _aus = d.pop("AUS", UNSET)
        aus: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AUS]
        if isinstance(_aus,  Unset):
            aus = UNSET
        else:
            aus = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AUS.from_dict(_aus)




        _nld = d.pop("NLD", UNSET)
        nld: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NLD]
        if isinstance(_nld,  Unset):
            nld = UNSET
        else:
            nld = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NLD.from_dict(_nld)




        _ita = d.pop("ITA", UNSET)
        ita: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ITA]
        if isinstance(_ita,  Unset):
            ita = UNSET
        else:
            ita = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ITA.from_dict(_ita)




        _zaf = d.pop("ZAF", UNSET)
        zaf: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ZAF]
        if isinstance(_zaf,  Unset):
            zaf = UNSET
        else:
            zaf = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ZAF.from_dict(_zaf)




        _bel = d.pop("BEL", UNSET)
        bel: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BEL]
        if isinstance(_bel,  Unset):
            bel = UNSET
        else:
            bel = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BEL.from_dict(_bel)




        _chn = d.pop("CHN", UNSET)
        chn: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CHN]
        if isinstance(_chn,  Unset):
            chn = UNSET
        else:
            chn = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CHN.from_dict(_chn)




        _tur = d.pop("TUR", UNSET)
        tur: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TUR]
        if isinstance(_tur,  Unset):
            tur = UNSET
        else:
            tur = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TUR.from_dict(_tur)




        _mex = d.pop("MEX", UNSET)
        mex: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MEX]
        if isinstance(_mex,  Unset):
            mex = UNSET
        else:
            mex = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MEX.from_dict(_mex)




        _che = d.pop("CHE", UNSET)
        che: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CHE]
        if isinstance(_che,  Unset):
            che = UNSET
        else:
            che = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CHE.from_dict(_che)




        _nor = d.pop("NOR", UNSET)
        nor: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NOR]
        if isinstance(_nor,  Unset):
            nor = UNSET
        else:
            nor = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NOR.from_dict(_nor)




        _are = d.pop("ARE", UNSET)
        are: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ARE]
        if isinstance(_are,  Unset):
            are = UNSET
        else:
            are = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ARE.from_dict(_are)




        _swe = d.pop("SWE", UNSET)
        swe: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SWE]
        if isinstance(_swe,  Unset):
            swe = UNSET
        else:
            swe = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SWE.from_dict(_swe)




        _pol = d.pop("POL", UNSET)
        pol: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0POL]
        if isinstance(_pol,  Unset):
            pol = UNSET
        else:
            pol = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0POL.from_dict(_pol)




        _idn = d.pop("IDN", UNSET)
        idn: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IDN]
        if isinstance(_idn,  Unset):
            idn = UNSET
        else:
            idn = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IDN.from_dict(_idn)




        _arg = d.pop("ARG", UNSET)
        arg: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ARG]
        if isinstance(_arg,  Unset):
            arg = UNSET
        else:
            arg = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ARG.from_dict(_arg)




        _prt = d.pop("PRT", UNSET)
        prt: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRT]
        if isinstance(_prt,  Unset):
            prt = UNSET
        else:
            prt = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRT.from_dict(_prt)




        _col = d.pop("COL", UNSET)
        col: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COL]
        if isinstance(_col,  Unset):
            col = UNSET
        else:
            col = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COL.from_dict(_col)




        _chl = d.pop("CHL", UNSET)
        chl: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CHL]
        if isinstance(_chl,  Unset):
            chl = UNSET
        else:
            chl = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CHL.from_dict(_chl)




        _pak = d.pop("PAK", UNSET)
        pak: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PAK]
        if isinstance(_pak,  Unset):
            pak = UNSET
        else:
            pak = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PAK.from_dict(_pak)




        _dnk = d.pop("DNK", UNSET)
        dnk: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DNK]
        if isinstance(_dnk,  Unset):
            dnk = UNSET
        else:
            dnk = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DNK.from_dict(_dnk)




        _jpn = d.pop("JPN", UNSET)
        jpn: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JPN]
        if isinstance(_jpn,  Unset):
            jpn = UNSET
        else:
            jpn = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JPN.from_dict(_jpn)




        _nga = d.pop("NGA", UNSET)
        nga: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NGA]
        if isinstance(_nga,  Unset):
            nga = UNSET
        else:
            nga = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NGA.from_dict(_nga)




        _sgp = d.pop("SGP", UNSET)
        sgp: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SGP]
        if isinstance(_sgp,  Unset):
            sgp = UNSET
        else:
            sgp = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SGP.from_dict(_sgp)




        _per = d.pop("PER", UNSET)
        per: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PER]
        if isinstance(_per,  Unset):
            per = UNSET
        else:
            per = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PER.from_dict(_per)




        _nzl = d.pop("NZL", UNSET)
        nzl: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NZL]
        if isinstance(_nzl,  Unset):
            nzl = UNSET
        else:
            nzl = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NZL.from_dict(_nzl)




        _aut = d.pop("AUT", UNSET)
        aut: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AUT]
        if isinstance(_aut,  Unset):
            aut = UNSET
        else:
            aut = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AUT.from_dict(_aut)




        _irl = d.pop("IRL", UNSET)
        irl: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IRL]
        if isinstance(_irl,  Unset):
            irl = UNSET
        else:
            irl = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IRL.from_dict(_irl)




        _mys = d.pop("MYS", UNSET)
        mys: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MYS]
        if isinstance(_mys,  Unset):
            mys = UNSET
        else:
            mys = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MYS.from_dict(_mys)




        _bgd = d.pop("BGD", UNSET)
        bgd: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BGD]
        if isinstance(_bgd,  Unset):
            bgd = UNSET
        else:
            bgd = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BGD.from_dict(_bgd)




        _egy = d.pop("EGY", UNSET)
        egy: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0EGY]
        if isinstance(_egy,  Unset):
            egy = UNSET
        else:
            egy = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0EGY.from_dict(_egy)




        _isr = d.pop("ISR", UNSET)
        isr: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ISR]
        if isinstance(_isr,  Unset):
            isr = UNSET
        else:
            isr = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ISR.from_dict(_isr)




        _sau = d.pop("SAU", UNSET)
        sau: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SAU]
        if isinstance(_sau,  Unset):
            sau = UNSET
        else:
            sau = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SAU.from_dict(_sau)




        _phl = d.pop("PHL", UNSET)
        phl: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PHL]
        if isinstance(_phl,  Unset):
            phl = UNSET
        else:
            phl = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PHL.from_dict(_phl)




        _fin = d.pop("FIN", UNSET)
        fin: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FIN]
        if isinstance(_fin,  Unset):
            fin = UNSET
        else:
            fin = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FIN.from_dict(_fin)




        _irn = d.pop("IRN", UNSET)
        irn: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IRN]
        if isinstance(_irn,  Unset):
            irn = UNSET
        else:
            irn = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IRN.from_dict(_irn)




        _rou = d.pop("ROU", UNSET)
        rou: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ROU]
        if isinstance(_rou,  Unset):
            rou = UNSET
        else:
            rou = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ROU.from_dict(_rou)




        _cze = d.pop("CZE", UNSET)
        cze: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CZE]
        if isinstance(_cze,  Unset):
            cze = UNSET
        else:
            cze = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CZE.from_dict(_cze)




        _grc = d.pop("GRC", UNSET)
        grc: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GRC]
        if isinstance(_grc,  Unset):
            grc = UNSET
        else:
            grc = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GRC.from_dict(_grc)




        _hkg = d.pop("HKG", UNSET)
        hkg: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HKG]
        if isinstance(_hkg,  Unset):
            hkg = UNSET
        else:
            hkg = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HKG.from_dict(_hkg)




        _hun = d.pop("HUN", UNSET)
        hun: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HUN]
        if isinstance(_hun,  Unset):
            hun = UNSET
        else:
            hun = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HUN.from_dict(_hun)




        _ken = d.pop("KEN", UNSET)
        ken: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KEN]
        if isinstance(_ken,  Unset):
            ken = UNSET
        else:
            ken = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KEN.from_dict(_ken)




        _mar = d.pop("MAR", UNSET)
        mar: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MAR]
        if isinstance(_mar,  Unset):
            mar = UNSET
        else:
            mar = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MAR.from_dict(_mar)




        _vnm = d.pop("VNM", UNSET)
        vnm: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VNM]
        if isinstance(_vnm,  Unset):
            vnm = UNSET
        else:
            vnm = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VNM.from_dict(_vnm)




        _rus = d.pop("RUS", UNSET)
        rus: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0RUS]
        if isinstance(_rus,  Unset):
            rus = UNSET
        else:
            rus = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0RUS.from_dict(_rus)




        _ukr = d.pop("UKR", UNSET)
        ukr: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UKR]
        if isinstance(_ukr,  Unset):
            ukr = UNSET
        else:
            ukr = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UKR.from_dict(_ukr)




        _ecu = d.pop("ECU", UNSET)
        ecu: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ECU]
        if isinstance(_ecu,  Unset):
            ecu = UNSET
        else:
            ecu = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ECU.from_dict(_ecu)




        _tha = d.pop("THA", UNSET)
        tha: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0THA]
        if isinstance(_tha,  Unset):
            tha = UNSET
        else:
            tha = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0THA.from_dict(_tha)




        _lka = d.pop("LKA", UNSET)
        lka: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LKA]
        if isinstance(_lka,  Unset):
            lka = UNSET
        else:
            lka = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LKA.from_dict(_lka)




        _kor = d.pop("KOR", UNSET)
        kor: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KOR]
        if isinstance(_kor,  Unset):
            kor = UNSET
        else:
            kor = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KOR.from_dict(_kor)




        _bgr = d.pop("BGR", UNSET)
        bgr: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BGR]
        if isinstance(_bgr,  Unset):
            bgr = UNSET
        else:
            bgr = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BGR.from_dict(_bgr)




        _gha = d.pop("GHA", UNSET)
        gha: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GHA]
        if isinstance(_gha,  Unset):
            gha = UNSET
        else:
            gha = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GHA.from_dict(_gha)




        _srb = d.pop("SRB", UNSET)
        srb: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SRB]
        if isinstance(_srb,  Unset):
            srb = UNSET
        else:
            srb = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SRB.from_dict(_srb)




        _twn = d.pop("TWN", UNSET)
        twn: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TWN]
        if isinstance(_twn,  Unset):
            twn = UNSET
        else:
            twn = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TWN.from_dict(_twn)




        _hrv = d.pop("HRV", UNSET)
        hrv: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HRV]
        if isinstance(_hrv,  Unset):
            hrv = UNSET
        else:
            hrv = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HRV.from_dict(_hrv)




        _ltu = d.pop("LTU", UNSET)
        ltu: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LTU]
        if isinstance(_ltu,  Unset):
            ltu = UNSET
        else:
            ltu = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LTU.from_dict(_ltu)




        _pri = d.pop("PRI", UNSET)
        pri: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRI]
        if isinstance(_pri,  Unset):
            pri = UNSET
        else:
            pri = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRI.from_dict(_pri)




        _svk = d.pop("SVK", UNSET)
        svk: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SVK]
        if isinstance(_svk,  Unset):
            svk = UNSET
        else:
            svk = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SVK.from_dict(_svk)




        _tun = d.pop("TUN", UNSET)
        tun: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TUN]
        if isinstance(_tun,  Unset):
            tun = UNSET
        else:
            tun = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TUN.from_dict(_tun)




        _est = d.pop("EST", UNSET)
        est: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0EST]
        if isinstance(_est,  Unset):
            est = UNSET
        else:
            est = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0EST.from_dict(_est)




        _ven = d.pop("VEN", UNSET)
        ven: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VEN]
        if isinstance(_ven,  Unset):
            ven = UNSET
        else:
            ven = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VEN.from_dict(_ven)




        _cri = d.pop("CRI", UNSET)
        cri: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CRI]
        if isinstance(_cri,  Unset):
            cri = UNSET
        else:
            cri = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CRI.from_dict(_cri)




        _pan = d.pop("PAN", UNSET)
        pan: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PAN]
        if isinstance(_pan,  Unset):
            pan = UNSET
        else:
            pan = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PAN.from_dict(_pan)




        _ury = d.pop("URY", UNSET)
        ury: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0URY]
        if isinstance(_ury,  Unset):
            ury = UNSET
        else:
            ury = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0URY.from_dict(_ury)




        _lbn = d.pop("LBN", UNSET)
        lbn: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LBN]
        if isinstance(_lbn,  Unset):
            lbn = UNSET
        else:
            lbn = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LBN.from_dict(_lbn)




        _lux = d.pop("LUX", UNSET)
        lux: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LUX]
        if isinstance(_lux,  Unset):
            lux = UNSET
        else:
            lux = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LUX.from_dict(_lux)




        _cyp = d.pop("CYP", UNSET)
        cyp: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CYP]
        if isinstance(_cyp,  Unset):
            cyp = UNSET
        else:
            cyp = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CYP.from_dict(_cyp)




        _npl = d.pop("NPL", UNSET)
        npl: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NPL]
        if isinstance(_npl,  Unset):
            npl = UNSET
        else:
            npl = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NPL.from_dict(_npl)




        _jor = d.pop("JOR", UNSET)
        jor: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JOR]
        if isinstance(_jor,  Unset):
            jor = UNSET
        else:
            jor = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JOR.from_dict(_jor)




        _svn = d.pop("SVN", UNSET)
        svn: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SVN]
        if isinstance(_svn,  Unset):
            svn = UNSET
        else:
            svn = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SVN.from_dict(_svn)




        _mtq = d.pop("MTQ", UNSET)
        mtq: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MTQ]
        if isinstance(_mtq,  Unset):
            mtq = UNSET
        else:
            mtq = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MTQ.from_dict(_mtq)




        _qat = d.pop("QAT", UNSET)
        qat: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0QAT]
        if isinstance(_qat,  Unset):
            qat = UNSET
        else:
            qat = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0QAT.from_dict(_qat)




        _glp = d.pop("GLP", UNSET)
        glp: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GLP]
        if isinstance(_glp,  Unset):
            glp = UNSET
        else:
            glp = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GLP.from_dict(_glp)




        _uga = d.pop("UGA", UNSET)
        uga: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UGA]
        if isinstance(_uga,  Unset):
            uga = UNSET
        else:
            uga = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UGA.from_dict(_uga)




        _dza = d.pop("DZA", UNSET)
        dza: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DZA]
        if isinstance(_dza,  Unset):
            dza = UNSET
        else:
            dza = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DZA.from_dict(_dza)




        _gtm = d.pop("GTM", UNSET)
        gtm: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GTM]
        if isinstance(_gtm,  Unset):
            gtm = UNSET
        else:
            gtm = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GTM.from_dict(_gtm)




        _cmr = d.pop("CMR", UNSET)
        cmr: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CMR]
        if isinstance(_cmr,  Unset):
            cmr = UNSET
        else:
            cmr = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CMR.from_dict(_cmr)




        _lva = d.pop("LVA", UNSET)
        lva: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LVA]
        if isinstance(_lva,  Unset):
            lva = UNSET
        else:
            lva = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LVA.from_dict(_lva)




        _dom = d.pop("DOM", UNSET)
        dom: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DOM]
        if isinstance(_dom,  Unset):
            dom = UNSET
        else:
            dom = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DOM.from_dict(_dom)




        _aze = d.pop("AZE", UNSET)
        aze: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AZE]
        if isinstance(_aze,  Unset):
            aze = UNSET
        else:
            aze = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AZE.from_dict(_aze)




        _geo = d.pop("GEO", UNSET)
        geo: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GEO]
        if isinstance(_geo,  Unset):
            geo = UNSET
        else:
            geo = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GEO.from_dict(_geo)




        _sen = d.pop("SEN", UNSET)
        sen: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SEN]
        if isinstance(_sen,  Unset):
            sen = UNSET
        else:
            sen = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SEN.from_dict(_sen)




        _tza = d.pop("TZA", UNSET)
        tza: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TZA]
        if isinstance(_tza,  Unset):
            tza = UNSET
        else:
            tza = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TZA.from_dict(_tza)




        _zwe = d.pop("ZWE", UNSET)
        zwe: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ZWE]
        if isinstance(_zwe,  Unset):
            zwe = UNSET
        else:
            zwe = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ZWE.from_dict(_zwe)




        _kwt = d.pop("KWT", UNSET)
        kwt: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KWT]
        if isinstance(_kwt,  Unset):
            kwt = UNSET
        else:
            kwt = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KWT.from_dict(_kwt)




        _mlt = d.pop("MLT", UNSET)
        mlt: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MLT]
        if isinstance(_mlt,  Unset):
            mlt = UNSET
        else:
            mlt = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MLT.from_dict(_mlt)




        _omn = d.pop("OMN", UNSET)
        omn: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0OMN]
        if isinstance(_omn,  Unset):
            omn = UNSET
        else:
            omn = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0OMN.from_dict(_omn)




        _bol = d.pop("BOL", UNSET)
        bol: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BOL]
        if isinstance(_bol,  Unset):
            bol = UNSET
        else:
            bol = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BOL.from_dict(_bol)




        _slv = d.pop("SLV", UNSET)
        slv: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SLV]
        if isinstance(_slv,  Unset):
            slv = UNSET
        else:
            slv = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SLV.from_dict(_slv)




        _arm = d.pop("ARM", UNSET)
        arm: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ARM]
        if isinstance(_arm,  Unset):
            arm = UNSET
        else:
            arm = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ARM.from_dict(_arm)




        _pry = d.pop("PRY", UNSET)
        pry: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRY]
        if isinstance(_pry,  Unset):
            pry = UNSET
        else:
            pry = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRY.from_dict(_pry)




        _irq = d.pop("IRQ", UNSET)
        irq: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IRQ]
        if isinstance(_irq,  Unset):
            irq = UNSET
        else:
            irq = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IRQ.from_dict(_irq)




        _khm = d.pop("KHM", UNSET)
        khm: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KHM]
        if isinstance(_khm,  Unset):
            khm = UNSET
        else:
            khm = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KHM.from_dict(_khm)




        _bih = d.pop("BIH", UNSET)
        bih: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BIH]
        if isinstance(_bih,  Unset):
            bih = UNSET
        else:
            bih = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BIH.from_dict(_bih)




        _ago = d.pop("AGO", UNSET)
        ago: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AGO]
        if isinstance(_ago,  Unset):
            ago = UNSET
        else:
            ago = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AGO.from_dict(_ago)




        _bhr = d.pop("BHR", UNSET)
        bhr: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BHR]
        if isinstance(_bhr,  Unset):
            bhr = UNSET
        else:
            bhr = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BHR.from_dict(_bhr)




        _alb = d.pop("ALB", UNSET)
        alb: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ALB]
        if isinstance(_alb,  Unset):
            alb = UNSET
        else:
            alb = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ALB.from_dict(_alb)




        _kaz = d.pop("KAZ", UNSET)
        kaz: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KAZ]
        if isinstance(_kaz,  Unset):
            kaz = UNSET
        else:
            kaz = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KAZ.from_dict(_kaz)




        _civ = d.pop("CIV", UNSET)
        civ: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CIV]
        if isinstance(_civ,  Unset):
            civ = UNSET
        else:
            civ = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CIV.from_dict(_civ)




        _eth = d.pop("ETH", UNSET)
        eth: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ETH]
        if isinstance(_eth,  Unset):
            eth = UNSET
        else:
            eth = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ETH.from_dict(_eth)




        _mus = d.pop("MUS", UNSET)
        mus: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MUS]
        if isinstance(_mus,  Unset):
            mus = UNSET
        else:
            mus = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MUS.from_dict(_mus)




        _zmb = d.pop("ZMB", UNSET)
        zmb: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ZMB]
        if isinstance(_zmb,  Unset):
            zmb = UNSET
        else:
            zmb = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ZMB.from_dict(_zmb)




        _mkd = d.pop("MKD", UNSET)
        mkd: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MKD]
        if isinstance(_mkd,  Unset):
            mkd = UNSET
        else:
            mkd = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MKD.from_dict(_mkd)




        _cod = d.pop("COD", UNSET)
        cod: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COD]
        if isinstance(_cod,  Unset):
            cod = UNSET
        else:
            cod = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COD.from_dict(_cod)




        _blr = d.pop("BLR", UNSET)
        blr: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BLR]
        if isinstance(_blr,  Unset):
            blr = UNSET
        else:
            blr = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BLR.from_dict(_blr)




        _moz = d.pop("MOZ", UNSET)
        moz: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MOZ]
        if isinstance(_moz,  Unset):
            moz = UNSET
        else:
            moz = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MOZ.from_dict(_moz)




        _reu = d.pop("REU", UNSET)
        reu: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0REU]
        if isinstance(_reu,  Unset):
            reu = UNSET
        else:
            reu = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0REU.from_dict(_reu)




        _tto = d.pop("TTO", UNSET)
        tto: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TTO]
        if isinstance(_tto,  Unset):
            tto = UNSET
        else:
            tto = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TTO.from_dict(_tto)




        _guf = d.pop("GUF", UNSET)
        guf: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GUF]
        if isinstance(_guf,  Unset):
            guf = UNSET
        else:
            guf = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GUF.from_dict(_guf)




        _isl = d.pop("ISL", UNSET)
        isl: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ISL]
        if isinstance(_isl,  Unset):
            isl = UNSET
        else:
            isl = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ISL.from_dict(_isl)




        _mmr = d.pop("MMR", UNSET)
        mmr: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MMR]
        if isinstance(_mmr,  Unset):
            mmr = UNSET
        else:
            mmr = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MMR.from_dict(_mmr)




        _hnd = d.pop("HND", UNSET)
        hnd: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HND]
        if isinstance(_hnd,  Unset):
            hnd = UNSET
        else:
            hnd = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HND.from_dict(_hnd)




        _rwa = d.pop("RWA", UNSET)
        rwa: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0RWA]
        if isinstance(_rwa,  Unset):
            rwa = UNSET
        else:
            rwa = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0RWA.from_dict(_rwa)




        _mdg = d.pop("MDG", UNSET)
        mdg: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MDG]
        if isinstance(_mdg,  Unset):
            mdg = UNSET
        else:
            mdg = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MDG.from_dict(_mdg)




        _ben = d.pop("BEN", UNSET)
        ben: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BEN]
        if isinstance(_ben,  Unset):
            ben = UNSET
        else:
            ben = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BEN.from_dict(_ben)




        _uzb = d.pop("UZB", UNSET)
        uzb: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UZB]
        if isinstance(_uzb,  Unset):
            uzb = UNSET
        else:
            uzb = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UZB.from_dict(_uzb)




        _nam = d.pop("NAM", UNSET)
        nam: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NAM]
        if isinstance(_nam,  Unset):
            nam = UNSET
        else:
            nam = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NAM.from_dict(_nam)




        _bwa = d.pop("BWA", UNSET)
        bwa: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BWA]
        if isinstance(_bwa,  Unset):
            bwa = UNSET
        else:
            bwa = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BWA.from_dict(_bwa)




        _mda = d.pop("MDA", UNSET)
        mda: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MDA]
        if isinstance(_mda,  Unset):
            mda = UNSET
        else:
            mda = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MDA.from_dict(_mda)




        _jey = d.pop("JEY", UNSET)
        jey: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JEY]
        if isinstance(_jey,  Unset):
            jey = UNSET
        else:
            jey = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JEY.from_dict(_jey)




        _nic = d.pop("NIC", UNSET)
        nic: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NIC]
        if isinstance(_nic,  Unset):
            nic = UNSET
        else:
            nic = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NIC.from_dict(_nic)




        _sdn = d.pop("SDN", UNSET)
        sdn: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SDN]
        if isinstance(_sdn,  Unset):
            sdn = UNSET
        else:
            sdn = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SDN.from_dict(_sdn)




        _jam = d.pop("JAM", UNSET)
        jam: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JAM]
        if isinstance(_jam,  Unset):
            jam = UNSET
        else:
            jam = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0JAM.from_dict(_jam)




        _imn = d.pop("IMN", UNSET)
        imn: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IMN]
        if isinstance(_imn,  Unset):
            imn = UNSET
        else:
            imn = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IMN.from_dict(_imn)




        _bfa = d.pop("BFA", UNSET)
        bfa: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BFA]
        if isinstance(_bfa,  Unset):
            bfa = UNSET
        else:
            bfa = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BFA.from_dict(_bfa)




        _mng = d.pop("MNG", UNSET)
        mng: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MNG]
        if isinstance(_mng,  Unset):
            mng = UNSET
        else:
            mng = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MNG.from_dict(_mng)




        _mne = d.pop("MNE", UNSET)
        mne: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MNE]
        if isinstance(_mne,  Unset):
            mne = UNSET
        else:
            mne = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MNE.from_dict(_mne)




        _mco = d.pop("MCO", UNSET)
        mco: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MCO]
        if isinstance(_mco,  Unset):
            mco = UNSET
        else:
            mco = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MCO.from_dict(_mco)




        _tgo = d.pop("TGO", UNSET)
        tgo: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TGO]
        if isinstance(_tgo,  Unset):
            tgo = UNSET
        else:
            tgo = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TGO.from_dict(_tgo)




        _afg = d.pop("AFG", UNSET)
        afg: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AFG]
        if isinstance(_afg,  Unset):
            afg = UNSET
        else:
            afg = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AFG.from_dict(_afg)




        _lby = d.pop("LBY", UNSET)
        lby: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LBY]
        if isinstance(_lby,  Unset):
            lby = UNSET
        else:
            lby = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LBY.from_dict(_lby)




        _xkx = d.pop("XKX", UNSET)
        xkx: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0XKX]
        if isinstance(_xkx,  Unset):
            xkx = UNSET
        else:
            xkx = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0XKX.from_dict(_xkx)




        _cym = d.pop("CYM", UNSET)
        cym: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CYM]
        if isinstance(_cym,  Unset):
            cym = UNSET
        else:
            cym = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CYM.from_dict(_cym)




        _mwi = d.pop("MWI", UNSET)
        mwi: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MWI]
        if isinstance(_mwi,  Unset):
            mwi = UNSET
        else:
            mwi = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MWI.from_dict(_mwi)




        _som = d.pop("SOM", UNSET)
        som: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SOM]
        if isinstance(_som,  Unset):
            som = UNSET
        else:
            som = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SOM.from_dict(_som)




        _png = d.pop("PNG", UNSET)
        png: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PNG]
        if isinstance(_png,  Unset):
            png = UNSET
        else:
            png = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PNG.from_dict(_png)




        _mdv = d.pop("MDV", UNSET)
        mdv: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MDV]
        if isinstance(_mdv,  Unset):
            mdv = UNSET
        else:
            mdv = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MDV.from_dict(_mdv)




        _mli = d.pop("MLI", UNSET)
        mli: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MLI]
        if isinstance(_mli,  Unset):
            mli = UNSET
        else:
            mli = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MLI.from_dict(_mli)




        _gin = d.pop("GIN", UNSET)
        gin: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GIN]
        if isinstance(_gin,  Unset):
            gin = UNSET
        else:
            gin = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GIN.from_dict(_gin)




        _pse = d.pop("PSE", UNSET)
        pse: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PSE]
        if isinstance(_pse,  Unset):
            pse = UNSET
        else:
            pse = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PSE.from_dict(_pse)




        _gab = d.pop("GAB", UNSET)
        gab: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GAB]
        if isinstance(_gab,  Unset):
            gab = UNSET
        else:
            gab = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GAB.from_dict(_gab)




        _lie = d.pop("LIE", UNSET)
        lie: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LIE]
        if isinstance(_lie,  Unset):
            lie = UNSET
        else:
            lie = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LIE.from_dict(_lie)




        _hti = d.pop("HTI", UNSET)
        hti: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HTI]
        if isinstance(_hti,  Unset):
            hti = UNSET
        else:
            hti = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HTI.from_dict(_hti)




        _syr = d.pop("SYR", UNSET)
        syr: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SYR]
        if isinstance(_syr,  Unset):
            syr = UNSET
        else:
            syr = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SYR.from_dict(_syr)




        _brb = d.pop("BRB", UNSET)
        brb: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BRB]
        if isinstance(_brb,  Unset):
            brb = UNSET
        else:
            brb = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BRB.from_dict(_brb)




        _yem = d.pop("YEM", UNSET)
        yem: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0YEM]
        if isinstance(_yem,  Unset):
            yem = UNSET
        else:
            yem = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0YEM.from_dict(_yem)




        _ggy = d.pop("GGY", UNSET)
        ggy: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GGY]
        if isinstance(_ggy,  Unset):
            ggy = UNSET
        else:
            ggy = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GGY.from_dict(_ggy)




        _ncl = d.pop("NCL", UNSET)
        ncl: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NCL]
        if isinstance(_ncl,  Unset):
            ncl = UNSET
        else:
            ncl = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NCL.from_dict(_ncl)




        _and_ = d.pop("AND", UNSET)
        and_: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AND]
        if isinstance(_and_,  Unset):
            and_ = UNSET
        else:
            and_ = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AND.from_dict(_and_)




        _sur = d.pop("SUR", UNSET)
        sur: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SUR]
        if isinstance(_sur,  Unset):
            sur = UNSET
        else:
            sur = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SUR.from_dict(_sur)




        _myt = d.pop("MYT", UNSET)
        myt: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MYT]
        if isinstance(_myt,  Unset):
            myt = UNSET
        else:
            myt = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MYT.from_dict(_myt)




        _kgz = d.pop("KGZ", UNSET)
        kgz: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KGZ]
        if isinstance(_kgz,  Unset):
            kgz = UNSET
        else:
            kgz = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KGZ.from_dict(_kgz)




        _bhs = d.pop("BHS", UNSET)
        bhs: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BHS]
        if isinstance(_bhs,  Unset):
            bhs = UNSET
        else:
            bhs = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BHS.from_dict(_bhs)




        _gib = d.pop("GIB", UNSET)
        gib: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GIB]
        if isinstance(_gib,  Unset):
            gib = UNSET
        else:
            gib = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GIB.from_dict(_gib)




        _cog = d.pop("COG", UNSET)
        cog: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COG]
        if isinstance(_cog,  Unset):
            cog = UNSET
        else:
            cog = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COG.from_dict(_cog)




        _fji = d.pop("FJI", UNSET)
        fji: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FJI]
        if isinstance(_fji,  Unset):
            fji = UNSET
        else:
            fji = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FJI.from_dict(_fji)




        _blm = d.pop("BLM", UNSET)
        blm: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BLM]
        if isinstance(_blm,  Unset):
            blm = UNSET
        else:
            blm = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BLM.from_dict(_blm)




        _cuw = d.pop("CUW", UNSET)
        cuw: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CUW]
        if isinstance(_cuw,  Unset):
            cuw = UNSET
        else:
            cuw = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CUW.from_dict(_cuw)




        _cub = d.pop("CUB", UNSET)
        cub: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CUB]
        if isinstance(_cub,  Unset):
            cub = UNSET
        else:
            cub = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CUB.from_dict(_cub)




        _sle = d.pop("SLE", UNSET)
        sle: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SLE]
        if isinstance(_sle,  Unset):
            sle = UNSET
        else:
            sle = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SLE.from_dict(_sle)




        _blz = d.pop("BLZ", UNSET)
        blz: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BLZ]
        if isinstance(_blz,  Unset):
            blz = UNSET
        else:
            blz = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BLZ.from_dict(_blz)




        _ner = d.pop("NER", UNSET)
        ner: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NER]
        if isinstance(_ner,  Unset):
            ner = UNSET
        else:
            ner = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NER.from_dict(_ner)




        _lbr = d.pop("LBR", UNSET)
        lbr: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LBR]
        if isinstance(_lbr,  Unset):
            lbr = UNSET
        else:
            lbr = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LBR.from_dict(_lbr)




        _vir = d.pop("VIR", UNSET)
        vir: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VIR]
        if isinstance(_vir,  Unset):
            vir = UNSET
        else:
            vir = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VIR.from_dict(_vir)




        _pyf = d.pop("PYF", UNSET)
        pyf: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PYF]
        if isinstance(_pyf,  Unset):
            pyf = UNSET
        else:
            pyf = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PYF.from_dict(_pyf)




        _gum = d.pop("GUM", UNSET)
        gum: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GUM]
        if isinstance(_gum,  Unset):
            gum = UNSET
        else:
            gum = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GUM.from_dict(_gum)




        _mrt = d.pop("MRT", UNSET)
        mrt: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MRT]
        if isinstance(_mrt,  Unset):
            mrt = UNSET
        else:
            mrt = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MRT.from_dict(_mrt)




        _abw = d.pop("ABW", UNSET)
        abw: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ABW]
        if isinstance(_abw,  Unset):
            abw = UNSET
        else:
            abw = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ABW.from_dict(_abw)




        _syc = d.pop("SYC", UNSET)
        syc: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SYC]
        if isinstance(_syc,  Unset):
            syc = UNSET
        else:
            syc = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SYC.from_dict(_syc)




        _guy = d.pop("GUY", UNSET)
        guy: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GUY]
        if isinstance(_guy,  Unset):
            guy = UNSET
        else:
            guy = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GUY.from_dict(_guy)




        _lso = d.pop("LSO", UNSET)
        lso: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LSO]
        if isinstance(_lso,  Unset):
            lso = UNSET
        else:
            lso = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LSO.from_dict(_lso)




        _swz = d.pop("SWZ", UNSET)
        swz: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SWZ]
        if isinstance(_swz,  Unset):
            swz = UNSET
        else:
            swz = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SWZ.from_dict(_swz)




        _ssd = d.pop("SSD", UNSET)
        ssd: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SSD]
        if isinstance(_ssd,  Unset):
            ssd = UNSET
        else:
            ssd = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SSD.from_dict(_ssd)




        _lca = d.pop("LCA", UNSET)
        lca: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LCA]
        if isinstance(_lca,  Unset):
            lca = UNSET
        else:
            lca = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LCA.from_dict(_lca)




        _mac = d.pop("MAC", UNSET)
        mac: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MAC]
        if isinstance(_mac,  Unset):
            mac = UNSET
        else:
            mac = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MAC.from_dict(_mac)




        _smr = d.pop("SMR", UNSET)
        smr: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SMR]
        if isinstance(_smr,  Unset):
            smr = UNSET
        else:
            smr = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SMR.from_dict(_smr)




        _lao = d.pop("LAO", UNSET)
        lao: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LAO]
        if isinstance(_lao,  Unset):
            lao = UNSET
        else:
            lao = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0LAO.from_dict(_lao)




        _brn = d.pop("BRN", UNSET)
        brn: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BRN]
        if isinstance(_brn,  Unset):
            brn = UNSET
        else:
            brn = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BRN.from_dict(_brn)




        _tcd = d.pop("TCD", UNSET)
        tcd: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TCD]
        if isinstance(_tcd,  Unset):
            tcd = UNSET
        else:
            tcd = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TCD.from_dict(_tcd)




        _bmu = d.pop("BMU", UNSET)
        bmu: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BMU]
        if isinstance(_bmu,  Unset):
            bmu = UNSET
        else:
            bmu = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BMU.from_dict(_bmu)




        _vgb = d.pop("VGB", UNSET)
        vgb: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VGB]
        if isinstance(_vgb,  Unset):
            vgb = UNSET
        else:
            vgb = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VGB.from_dict(_vgb)




        _prk = d.pop("PRK", UNSET)
        prk: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRK]
        if isinstance(_prk,  Unset):
            prk = UNSET
        else:
            prk = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PRK.from_dict(_prk)




        _btn = d.pop("BTN", UNSET)
        btn: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BTN]
        if isinstance(_btn,  Unset):
            btn = UNSET
        else:
            btn = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BTN.from_dict(_btn)




        _bdi = d.pop("BDI", UNSET)
        bdi: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BDI]
        if isinstance(_bdi,  Unset):
            bdi = UNSET
        else:
            bdi = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BDI.from_dict(_bdi)




        _fro = d.pop("FRO", UNSET)
        fro: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FRO]
        if isinstance(_fro,  Unset):
            fro = UNSET
        else:
            fro = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FRO.from_dict(_fro)




        _tjk = d.pop("TJK", UNSET)
        tjk: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TJK]
        if isinstance(_tjk,  Unset):
            tjk = UNSET
        else:
            tjk = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TJK.from_dict(_tjk)




        _gmb = d.pop("GMB", UNSET)
        gmb: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GMB]
        if isinstance(_gmb,  Unset):
            gmb = UNSET
        else:
            gmb = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GMB.from_dict(_gmb)




        _stp = d.pop("STP", UNSET)
        stp: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0STP]
        if isinstance(_stp,  Unset):
            stp = UNSET
        else:
            stp = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0STP.from_dict(_stp)




        _ant = d.pop("ANT", UNSET)
        ant: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ANT]
        if isinstance(_ant,  Unset):
            ant = UNSET
        else:
            ant = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ANT.from_dict(_ant)




        _vct = d.pop("VCT", UNSET)
        vct: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VCT]
        if isinstance(_vct,  Unset):
            vct = UNSET
        else:
            vct = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VCT.from_dict(_vct)




        _dji = d.pop("DJI", UNSET)
        dji: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DJI]
        if isinstance(_dji,  Unset):
            dji = UNSET
        else:
            dji = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DJI.from_dict(_dji)




        _cpv = d.pop("CPV", UNSET)
        cpv: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CPV]
        if isinstance(_cpv,  Unset):
            cpv = UNSET
        else:
            cpv = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CPV.from_dict(_cpv)




        _tkm = d.pop("TKM", UNSET)
        tkm: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TKM]
        if isinstance(_tkm,  Unset):
            tkm = UNSET
        else:
            tkm = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TKM.from_dict(_tkm)




        _atg = d.pop("ATG", UNSET)
        atg: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ATG]
        if isinstance(_atg,  Unset):
            atg = UNSET
        else:
            atg = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ATG.from_dict(_atg)




        _tca = d.pop("TCA", UNSET)
        tca: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TCA]
        if isinstance(_tca,  Unset):
            tca = UNSET
        else:
            tca = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TCA.from_dict(_tca)




        _kna = d.pop("KNA", UNSET)
        kna: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KNA]
        if isinstance(_kna,  Unset):
            kna = UNSET
        else:
            kna = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KNA.from_dict(_kna)




        _grd = d.pop("GRD", UNSET)
        grd: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GRD]
        if isinstance(_grd,  Unset):
            grd = UNSET
        else:
            grd = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GRD.from_dict(_grd)




        _asm = d.pop("ASM", UNSET)
        asm: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ASM]
        if isinstance(_asm,  Unset):
            asm = UNSET
        else:
            asm = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ASM.from_dict(_asm)




        _vut = d.pop("VUT", UNSET)
        vut: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VUT]
        if isinstance(_vut,  Unset):
            vut = UNSET
        else:
            vut = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VUT.from_dict(_vut)




        _gnq = d.pop("GNQ", UNSET)
        gnq: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GNQ]
        if isinstance(_gnq,  Unset):
            gnq = UNSET
        else:
            gnq = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GNQ.from_dict(_gnq)




        _grl = d.pop("GRL", UNSET)
        grl: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GRL]
        if isinstance(_grl,  Unset):
            grl = UNSET
        else:
            grl = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GRL.from_dict(_grl)




        _sxm = d.pop("SXM", UNSET)
        sxm: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SXM]
        if isinstance(_sxm,  Unset):
            sxm = UNSET
        else:
            sxm = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SXM.from_dict(_sxm)




        _mnp = d.pop("MNP", UNSET)
        mnp: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MNP]
        if isinstance(_mnp,  Unset):
            mnp = UNSET
        else:
            mnp = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MNP.from_dict(_mnp)




        _com = d.pop("COM", UNSET)
        com: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COM]
        if isinstance(_com,  Unset):
            com = UNSET
        else:
            com = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COM.from_dict(_com)




        _tls = d.pop("TLS", UNSET)
        tls: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TLS]
        if isinstance(_tls,  Unset):
            tls = UNSET
        else:
            tls = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TLS.from_dict(_tls)




        _sjm = d.pop("SJM", UNSET)
        sjm: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SJM]
        if isinstance(_sjm,  Unset):
            sjm = UNSET
        else:
            sjm = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SJM.from_dict(_sjm)




        _caf = d.pop("CAF", UNSET)
        caf: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CAF]
        if isinstance(_caf,  Unset):
            caf = UNSET
        else:
            caf = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CAF.from_dict(_caf)




        _dma = d.pop("DMA", UNSET)
        dma: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DMA]
        if isinstance(_dma,  Unset):
            dma = UNSET
        else:
            dma = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0DMA.from_dict(_dma)




        _maf = d.pop("MAF", UNSET)
        maf: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MAF]
        if isinstance(_maf,  Unset):
            maf = UNSET
        else:
            maf = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MAF.from_dict(_maf)




        _wsm = d.pop("WSM", UNSET)
        wsm: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0WSM]
        if isinstance(_wsm,  Unset):
            wsm = UNSET
        else:
            wsm = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0WSM.from_dict(_wsm)




        _bes = d.pop("BES", UNSET)
        bes: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BES]
        if isinstance(_bes,  Unset):
            bes = UNSET
        else:
            bes = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BES.from_dict(_bes)




        _mhl = d.pop("MHL", UNSET)
        mhl: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MHL]
        if isinstance(_mhl,  Unset):
            mhl = UNSET
        else:
            mhl = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MHL.from_dict(_mhl)




        _aia = d.pop("AIA", UNSET)
        aia: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AIA]
        if isinstance(_aia,  Unset):
            aia = UNSET
        else:
            aia = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0AIA.from_dict(_aia)




        _ton = d.pop("TON", UNSET)
        ton: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TON]
        if isinstance(_ton,  Unset):
            ton = UNSET
        else:
            ton = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TON.from_dict(_ton)




        _cok = d.pop("COK", UNSET)
        cok: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COK]
        if isinstance(_cok,  Unset):
            cok = UNSET
        else:
            cok = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0COK.from_dict(_cok)




        _slb = d.pop("SLB", UNSET)
        slb: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SLB]
        if isinstance(_slb,  Unset):
            slb = UNSET
        else:
            slb = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SLB.from_dict(_slb)




        _spm = d.pop("SPM", UNSET)
        spm: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SPM]
        if isinstance(_spm,  Unset):
            spm = UNSET
        else:
            spm = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SPM.from_dict(_spm)




        _gnb = d.pop("GNB", UNSET)
        gnb: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GNB]
        if isinstance(_gnb,  Unset):
            gnb = UNSET
        else:
            gnb = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0GNB.from_dict(_gnb)




        _ata = d.pop("ATA", UNSET)
        ata: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ATA]
        if isinstance(_ata,  Unset):
            ata = UNSET
        else:
            ata = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ATA.from_dict(_ata)




        _tuv = d.pop("TUV", UNSET)
        tuv: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TUV]
        if isinstance(_tuv,  Unset):
            tuv = UNSET
        else:
            tuv = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TUV.from_dict(_tuv)




        _ala = d.pop("ALA", UNSET)
        ala: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ALA]
        if isinstance(_ala,  Unset):
            ala = UNSET
        else:
            ala = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ALA.from_dict(_ala)




        _iot = d.pop("IOT", UNSET)
        iot: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IOT]
        if isinstance(_iot,  Unset):
            iot = UNSET
        else:
            iot = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0IOT.from_dict(_iot)




        _eri = d.pop("ERI", UNSET)
        eri: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ERI]
        if isinstance(_eri,  Unset):
            eri = UNSET
        else:
            eri = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ERI.from_dict(_eri)




        _plw = d.pop("PLW", UNSET)
        plw: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PLW]
        if isinstance(_plw,  Unset):
            plw = UNSET
        else:
            plw = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PLW.from_dict(_plw)




        _fsm = d.pop("FSM", UNSET)
        fsm: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FSM]
        if isinstance(_fsm,  Unset):
            fsm = UNSET
        else:
            fsm = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FSM.from_dict(_fsm)




        _nru = d.pop("NRU", UNSET)
        nru: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NRU]
        if isinstance(_nru,  Unset):
            nru = UNSET
        else:
            nru = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NRU.from_dict(_nru)




        _pcn = d.pop("PCN", UNSET)
        pcn: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PCN]
        if isinstance(_pcn,  Unset):
            pcn = UNSET
        else:
            pcn = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0PCN.from_dict(_pcn)




        _flk = d.pop("FLK", UNSET)
        flk: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FLK]
        if isinstance(_flk,  Unset):
            flk = UNSET
        else:
            flk = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0FLK.from_dict(_flk)




        _msr = d.pop("MSR", UNSET)
        msr: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MSR]
        if isinstance(_msr,  Unset):
            msr = UNSET
        else:
            msr = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0MSR.from_dict(_msr)




        _vat = d.pop("VAT", UNSET)
        vat: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VAT]
        if isinstance(_vat,  Unset):
            vat = UNSET
        else:
            vat = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0VAT.from_dict(_vat)




        _kir = d.pop("KIR", UNSET)
        kir: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KIR]
        if isinstance(_kir,  Unset):
            kir = UNSET
        else:
            kir = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0KIR.from_dict(_kir)




        _shn = d.pop("SHN", UNSET)
        shn: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SHN]
        if isinstance(_shn,  Unset):
            shn = UNSET
        else:
            shn = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SHN.from_dict(_shn)




        _niu = d.pop("NIU", UNSET)
        niu: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NIU]
        if isinstance(_niu,  Unset):
            niu = UNSET
        else:
            niu = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NIU.from_dict(_niu)




        _wlf = d.pop("WLF", UNSET)
        wlf: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0WLF]
        if isinstance(_wlf,  Unset):
            wlf = UNSET
        else:
            wlf = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0WLF.from_dict(_wlf)




        _hmd = d.pop("HMD", UNSET)
        hmd: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HMD]
        if isinstance(_hmd,  Unset):
            hmd = UNSET
        else:
            hmd = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0HMD.from_dict(_hmd)




        _cxr = d.pop("CXR", UNSET)
        cxr: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CXR]
        if isinstance(_cxr,  Unset):
            cxr = UNSET
        else:
            cxr = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CXR.from_dict(_cxr)




        _nfk = d.pop("NFK", UNSET)
        nfk: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NFK]
        if isinstance(_nfk,  Unset):
            nfk = UNSET
        else:
            nfk = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0NFK.from_dict(_nfk)




        _atf = d.pop("ATF", UNSET)
        atf: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ATF]
        if isinstance(_atf,  Unset):
            atf = UNSET
        else:
            atf = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ATF.from_dict(_atf)




        _cck = d.pop("CCK", UNSET)
        cck: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CCK]
        if isinstance(_cck,  Unset):
            cck = UNSET
        else:
            cck = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0CCK.from_dict(_cck)




        _sgs = d.pop("SGS", UNSET)
        sgs: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SGS]
        if isinstance(_sgs,  Unset):
            sgs = UNSET
        else:
            sgs = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0SGS.from_dict(_sgs)




        _bvt = d.pop("BVT", UNSET)
        bvt: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BVT]
        if isinstance(_bvt,  Unset):
            bvt = UNSET
        else:
            bvt = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0BVT.from_dict(_bvt)




        _umi = d.pop("UMI", UNSET)
        umi: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UMI]
        if isinstance(_umi,  Unset):
            umi = UNSET
        else:
            umi = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0UMI.from_dict(_umi)




        _esh = d.pop("ESH", UNSET)
        esh: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ESH]
        if isinstance(_esh,  Unset):
            esh = UNSET
        else:
            esh = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0ESH.from_dict(_esh)




        _tkl = d.pop("TKL", UNSET)
        tkl: Union[Unset, GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TKL]
        if isinstance(_tkl,  Unset):
            tkl = UNSET
        else:
            tkl = GetSavedSearchRunCompaniesResponse200OutputCompaniesItemCompanyLiJobPostsStatsType0CountryLocationStatsType0TKL.from_dict(_tkl)




        get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0 = cls(
            usa=usa,
            gbr=gbr,
            fra=fra,
            ind=ind,
            bra=bra,
            deu=deu,
            esp=esp,
            can=can,
            aus=aus,
            nld=nld,
            ita=ita,
            zaf=zaf,
            bel=bel,
            chn=chn,
            tur=tur,
            mex=mex,
            che=che,
            nor=nor,
            are=are,
            swe=swe,
            pol=pol,
            idn=idn,
            arg=arg,
            prt=prt,
            col=col,
            chl=chl,
            pak=pak,
            dnk=dnk,
            jpn=jpn,
            nga=nga,
            sgp=sgp,
            per=per,
            nzl=nzl,
            aut=aut,
            irl=irl,
            mys=mys,
            bgd=bgd,
            egy=egy,
            isr=isr,
            sau=sau,
            phl=phl,
            fin=fin,
            irn=irn,
            rou=rou,
            cze=cze,
            grc=grc,
            hkg=hkg,
            hun=hun,
            ken=ken,
            mar=mar,
            vnm=vnm,
            rus=rus,
            ukr=ukr,
            ecu=ecu,
            tha=tha,
            lka=lka,
            kor=kor,
            bgr=bgr,
            gha=gha,
            srb=srb,
            twn=twn,
            hrv=hrv,
            ltu=ltu,
            pri=pri,
            svk=svk,
            tun=tun,
            est=est,
            ven=ven,
            cri=cri,
            pan=pan,
            ury=ury,
            lbn=lbn,
            lux=lux,
            cyp=cyp,
            npl=npl,
            jor=jor,
            svn=svn,
            mtq=mtq,
            qat=qat,
            glp=glp,
            uga=uga,
            dza=dza,
            gtm=gtm,
            cmr=cmr,
            lva=lva,
            dom=dom,
            aze=aze,
            geo=geo,
            sen=sen,
            tza=tza,
            zwe=zwe,
            kwt=kwt,
            mlt=mlt,
            omn=omn,
            bol=bol,
            slv=slv,
            arm=arm,
            pry=pry,
            irq=irq,
            khm=khm,
            bih=bih,
            ago=ago,
            bhr=bhr,
            alb=alb,
            kaz=kaz,
            civ=civ,
            eth=eth,
            mus=mus,
            zmb=zmb,
            mkd=mkd,
            cod=cod,
            blr=blr,
            moz=moz,
            reu=reu,
            tto=tto,
            guf=guf,
            isl=isl,
            mmr=mmr,
            hnd=hnd,
            rwa=rwa,
            mdg=mdg,
            ben=ben,
            uzb=uzb,
            nam=nam,
            bwa=bwa,
            mda=mda,
            jey=jey,
            nic=nic,
            sdn=sdn,
            jam=jam,
            imn=imn,
            bfa=bfa,
            mng=mng,
            mne=mne,
            mco=mco,
            tgo=tgo,
            afg=afg,
            lby=lby,
            xkx=xkx,
            cym=cym,
            mwi=mwi,
            som=som,
            png=png,
            mdv=mdv,
            mli=mli,
            gin=gin,
            pse=pse,
            gab=gab,
            lie=lie,
            hti=hti,
            syr=syr,
            brb=brb,
            yem=yem,
            ggy=ggy,
            ncl=ncl,
            and_=and_,
            sur=sur,
            myt=myt,
            kgz=kgz,
            bhs=bhs,
            gib=gib,
            cog=cog,
            fji=fji,
            blm=blm,
            cuw=cuw,
            cub=cub,
            sle=sle,
            blz=blz,
            ner=ner,
            lbr=lbr,
            vir=vir,
            pyf=pyf,
            gum=gum,
            mrt=mrt,
            abw=abw,
            syc=syc,
            guy=guy,
            lso=lso,
            swz=swz,
            ssd=ssd,
            lca=lca,
            mac=mac,
            smr=smr,
            lao=lao,
            brn=brn,
            tcd=tcd,
            bmu=bmu,
            vgb=vgb,
            prk=prk,
            btn=btn,
            bdi=bdi,
            fro=fro,
            tjk=tjk,
            gmb=gmb,
            stp=stp,
            ant=ant,
            vct=vct,
            dji=dji,
            cpv=cpv,
            tkm=tkm,
            atg=atg,
            tca=tca,
            kna=kna,
            grd=grd,
            asm=asm,
            vut=vut,
            gnq=gnq,
            grl=grl,
            sxm=sxm,
            mnp=mnp,
            com=com,
            tls=tls,
            sjm=sjm,
            caf=caf,
            dma=dma,
            maf=maf,
            wsm=wsm,
            bes=bes,
            mhl=mhl,
            aia=aia,
            ton=ton,
            cok=cok,
            slb=slb,
            spm=spm,
            gnb=gnb,
            ata=ata,
            tuv=tuv,
            ala=ala,
            iot=iot,
            eri=eri,
            plw=plw,
            fsm=fsm,
            nru=nru,
            pcn=pcn,
            flk=flk,
            msr=msr,
            vat=vat,
            kir=kir,
            shn=shn,
            niu=niu,
            wlf=wlf,
            hmd=hmd,
            cxr=cxr,
            nfk=nfk,
            atf=atf,
            cck=cck,
            sgs=sgs,
            bvt=bvt,
            umi=umi,
            esh=esh,
            tkl=tkl,
        )

        return get_saved_search_run_companies_response_200_output_companies_item_company_li_job_posts_stats_type_0_country_location_stats_type_0

